searchData={"content_type":"text/markdown","items":[{"doc":"# NumberF\n\nA comprehensive utility library for number formatting, calculation, and manipulation in Elixir.","ref":"NumberF.html","title":"NumberF","type":"module"},{"doc":"- **Number Formatting**: Format numbers as currency, with commas, custom delimiters, abbreviated forms (K, M, B)\n- **Text Representation**: Convert numbers to words, ordinals, Roman numerals\n- **Financial Calculations**: Simple/compound interest, EMI calculations, currency conversions, tax calculations\n- **Statistical Functions**: Mean, median, mode, standard deviation, variance\n- **Date Calculations**: Age calculation, business days, payment terms\n- **Validation**: Credit card validation (Luhn algorithm), number format validation\n- **String Generation**: Random string generation, password creation\n- **Type Conversions**: Convert between numeric types and formats\n- **Memory Size**: Convert byte counts to human-readable formats\n- **Phone Formatting**: Format phone numbers based on country codes\n- **Unit Conversion**: Convert between metric and imperial units\n- **Tax Calculations**: VAT, sales tax, income tax calculations\n- **Precision Handling**: Different rounding strategies and precision handling\n- **Internationalization**: Format numbers according to locale conventions","ref":"NumberF.html#module-features","title":"Features - NumberF","type":"module"},{"doc":"Add `number_f` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:number_f, \"~> 0.2.0\"}\n]\nend\n```","ref":"NumberF.html#module-installation","title":"Installation - NumberF","type":"module"},{"doc":"","ref":"NumberF.html#module-key-functionality","title":"Key Functionality - NumberF","type":"module"},{"doc":"NumberF provides comprehensive formatting capabilities for currency and numbers:\n\n```elixir\n# Format as currency with default (ZMW)\nNumberF.currency(1234.567)                    # => \"ZMW 1,234.57\"\n\n# Format as US Dollars with 2 decimal places\nNumberF.currency(1234.567, \"USD\", 2)          # => \"USD 1,234.57\"\n\n# Format with French locale (space as thousands separator, comma as decimal)\nNumberF.format_number(1234567.89, \"fr-FR\")    # => \"1 234 567,89\"\n```","ref":"NumberF.html#module-currency-number-formatting","title":"Currency & Number Formatting - NumberF","type":"module"},{"doc":"Convert numeric values to their word representations:\n\n```elixir\n# Convert whole number with default currency (Kwacha)\nNumberF.to_words(42)                          # => \"Forty Two Kwacha\"\n\n# Convert decimal with custom currency\nNumberF.to_words(42.75, \"Dollars\", \"Cents\")   # => \"Forty Two Dollars And Seventy Five Cents\"\n\n# Advanced internationalization\nNumberF.spell_number(42, \"fr\")                # => \"Quarante-deux\"\n```","ref":"NumberF.html#module-number-to-words-conversion","title":"Number to Words Conversion - NumberF","type":"module"},{"doc":"Perform complex financial operations with ease:\n\n```elixir\n# Calculate simple interest (principal, rate, time)\nNumberF.simple_interest(1000, 0.05, 2)        # => 100.0\n\n# Calculate compound interest with monthly compounding\nNumberF.compound_interest(1000, 0.05, 2, 12)  # => 104.94\n\n# Calculate loan EMI (principal, rate, term in months)\nNumberF.calculate_emi(100000, 0.10, 12)       # => 8791.59\n\n# Calculate VAT\nNumberF.calculate_vat(100, 0.2)               # => %{net: 100.0, vat: 20.0, gross: 120.0}\n```","ref":"NumberF.html#module-financial-calculations","title":"Financial Calculations - NumberF","type":"module"},{"doc":"Analyze numerical data with statistical functions:\n\n```elixir\nNumberF.mean([1, 2, 3, 4, 5])                 # => 3.0\nNumberF.median([1, 3, 5, 7, 9])               # => 5\nNumberF.mode([1, 2, 2, 3, 3, 3, 4])           # => [3]\nNumberF.standard_deviation([2, 4, 4, 4, 5, 5, 7, 9])  # => 2.0\n```","ref":"NumberF.html#module-statistical-functions","title":"Statistical Functions - NumberF","type":"module"},{"doc":"Format numbers according to locale-specific conventions:\n\n```elixir\n# Format with US locale\nNumberF.format_currency(1234.56, \"en-US\")     # => \"$1,234.56\"\n\n# Format with French locale\nNumberF.format_currency(1234.56, \"fr-FR\")     # => \"1 234,56 €\"\n\n# Format with German locale but using USD\nNumberF.format_currency(1234.56, \"de-DE\", currency_code: \"USD\")  # => \"1.234,56 $\"\n```","ref":"NumberF.html#module-internationalization-localization","title":"Internationalization & Localization - NumberF","type":"module"},{"doc":"NumberF is organized into specialized modules for different functionality areas:\n\n- **Core**: `NumberF`, `NumberF.Registry`\n- **Calculation**: `NumberF.Calculations`, `NumberF.Financial`, `NumberF.Statistics`, `NumberF.Precision`, `NumberF.Tax`\n- **Formatting**: `NumberF.Currency`, `NumberF.Formatter`, `NumberF.CustomFormatter`, `NumberF.Currencies`\n- **Conversion**: `NumberF.Metrics`, `NumberF.NumbersToWords`, `NumberF.NumberToWord`\n- **Validation**: `NumberF.Validation`\n- **Utilities**: `NumberF.Memory`, `NumberF.Randomizer`, `NumberF.Helper`\n- **Date**: `NumberF.DateCalculations`\n- **I18n**: `NumberF.I18n`\n\nWhile specific functions can be accessed through their respective modules,\nmost common functionality is available directly from the main `NumberF` module\nfor convenience.\n\nFor more information, see the [full documentation on HexDocs](https://hexdocs.pm/number_f).","ref":"NumberF.html#module-module-organization","title":"Module Organization - NumberF","type":"module"},{"doc":"Formats large numbers as K, M, B (e.g., 1.2K, 3.4M).","ref":"NumberF.html#abbreviate_number/2","title":"NumberF.abbreviate_number/2","type":"function"},{"doc":"- `number`: The number to abbreviate\n  - `precision`: Number of decimal places (default: 1)","ref":"NumberF.html#abbreviate_number/2-parameters","title":"Parameters - NumberF.abbreviate_number/2","type":"function"},{"doc":"iex> NumberF.abbreviate_number(1234)\n    \"1.2K\"\n\n    iex> NumberF.abbreviate_number(1234567)\n    \"1.2M\"\n\n    iex> NumberF.abbreviate_number(1234567890)\n    \"1.2B\"","ref":"NumberF.html#abbreviate_number/2-examples","title":"Examples - NumberF.abbreviate_number/2","type":"function"},{"doc":"Checks if two floating point numbers are approximately equal.","ref":"NumberF.html#approximately_equal/3","title":"NumberF.approximately_equal/3","type":"function"},{"doc":"- `a`: First number\n  - `b`: Second number\n  - `epsilon`: Maximum allowed difference (default: 1.0e-10)","ref":"NumberF.html#approximately_equal/3-parameters","title":"Parameters - NumberF.approximately_equal/3","type":"function"},{"doc":"iex> NumberF.approximately_equal(0.1 + 0.2, 0.3)\n    true\n\n    iex> NumberF.approximately_equal(0.1, 0.2)\n    false","ref":"NumberF.html#approximately_equal/3-examples","title":"Examples - NumberF.approximately_equal/3","type":"function"},{"doc":"Rounds a number using banker's rounding (round to even).\nThis is more statistically unbiased than standard rounding.","ref":"NumberF.html#bankers_round/2","title":"NumberF.bankers_round/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#bankers_round/2-parameters","title":"Parameters - NumberF.bankers_round/2","type":"function"},{"doc":"iex> NumberF.bankers_round(2.5, 0)\n    2.0\n\n    iex> NumberF.bankers_round(3.5, 0)\n    4.0","ref":"NumberF.html#bankers_round/2-examples","title":"Examples - NumberF.bankers_round/2","type":"function"},{"doc":"Calculates the number of business days between two dates.","ref":"NumberF.html#business_days_between/2","title":"NumberF.business_days_between/2","type":"function"},{"doc":"- `date1`: The first date\n  - `date2`: The second date","ref":"NumberF.html#business_days_between/2-parameters","title":"Parameters - NumberF.business_days_between/2","type":"function"},{"doc":"iex> NumberF.business_days_between(~D[2023-01-02], ~D[2023-01-08])\n    5","ref":"NumberF.html#business_days_between/2-examples","title":"Examples - NumberF.business_days_between/2","type":"function"},{"doc":"Calculates age based on birth date.","ref":"NumberF.html#calculate_age/1","title":"NumberF.calculate_age/1","type":"function"},{"doc":"- `birth_date`: Birth date as Date struct","ref":"NumberF.html#calculate_age/1-parameters","title":"Parameters - NumberF.calculate_age/1","type":"function"},{"doc":"iex> birth_date = ~D[1990-01-15]\n    iex> age = NumberF.calculate_age(birth_date)\n    # Returns the current age based on today's date","ref":"NumberF.html#calculate_age/1-examples","title":"Examples - NumberF.calculate_age/1","type":"function"},{"doc":"Calculates Equated Monthly Installment (EMI) for loans.","ref":"NumberF.html#calculate_emi/3","title":"NumberF.calculate_emi/3","type":"function"},{"doc":"- `principal`: The loan amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `term_months`: The loan term in months","ref":"NumberF.html#calculate_emi/3-parameters","title":"Parameters - NumberF.calculate_emi/3","type":"function"},{"doc":"iex> NumberF.calculate_emi(100000, 0.10, 12)\n    8791.59","ref":"NumberF.html#calculate_emi/3-examples","title":"Examples - NumberF.calculate_emi/3","type":"function"},{"doc":"Calculates sales tax for a given amount and rate.","ref":"NumberF.html#calculate_sales_tax/3","title":"NumberF.calculate_sales_tax/3","type":"function"},{"doc":"- `amount`: The amount before tax\n  - `rate`: The sales tax rate as a decimal (e.g., 0.06 for 6%)\n  - `options`: Additional options\n    - `:round_to`: Round the tax amount to the nearest value (default: 0.01)","ref":"NumberF.html#calculate_sales_tax/3-parameters","title":"Parameters - NumberF.calculate_sales_tax/3","type":"function"},{"doc":"iex> NumberF.calculate_sales_tax(100, 0.06)\n    %{subtotal: 100.0, tax: 6.0, total: 106.0}","ref":"NumberF.html#calculate_sales_tax/3-examples","title":"Examples - NumberF.calculate_sales_tax/3","type":"function"},{"doc":"Calculates Value Added Tax (VAT) for a given amount and rate.","ref":"NumberF.html#calculate_vat/3","title":"NumberF.calculate_vat/3","type":"function"},{"doc":"- `amount`: The amount before tax\n  - `rate`: The VAT rate as a decimal (e.g., 0.2 for 20%)\n  - `included`: Whether the amount already includes VAT (default: false)","ref":"NumberF.html#calculate_vat/3-parameters","title":"Parameters - NumberF.calculate_vat/3","type":"function"},{"doc":"iex> NumberF.calculate_vat(100, 0.2)\n    %{net: 100.0, vat: 20.0, gross: 120.0}\n\n    iex> NumberF.calculate_vat(120, 0.2, true)\n    %{net: 100.0, vat: 20.0, gross: 120.0}","ref":"NumberF.html#calculate_vat/3-examples","title":"Examples - NumberF.calculate_vat/3","type":"function"},{"doc":"Converts Celsius to Fahrenheit.","ref":"NumberF.html#celsius_to_fahrenheit/1","title":"NumberF.celsius_to_fahrenheit/1","type":"function"},{"doc":"- `celsius`: The temperature in Celsius","ref":"NumberF.html#celsius_to_fahrenheit/1-parameters","title":"Parameters - NumberF.celsius_to_fahrenheit/1","type":"function"},{"doc":"iex> NumberF.celsius_to_fahrenheit(0)\n    32.0\n\n    iex> NumberF.celsius_to_fahrenheit(100)\n    212.0","ref":"NumberF.html#celsius_to_fahrenheit/1-examples","title":"Examples - NumberF.celsius_to_fahrenheit/1","type":"function"},{"doc":"Converts centimeters to inches.","ref":"NumberF.html#cm_to_inches/1","title":"NumberF.cm_to_inches/1","type":"function"},{"doc":"- `cm`: The length in centimeters","ref":"NumberF.html#cm_to_inches/1-parameters","title":"Parameters - NumberF.cm_to_inches/1","type":"function"},{"doc":"iex> NumberF.cm_to_inches(25.4)\n    10.0","ref":"NumberF.html#cm_to_inches/1-examples","title":"Examples - NumberF.cm_to_inches/1","type":"function"},{"doc":"Calculates combinations (n choose k).","ref":"NumberF.html#combinations/2","title":"NumberF.combinations/2","type":"function"},{"doc":"- `n`: The total number of items\n  - `k`: The number of items to choose","ref":"NumberF.html#combinations/2-parameters","title":"Parameters - NumberF.combinations/2","type":"function"},{"doc":"iex> NumberF.combinations(5, 2)\n    10.0\n\n    iex> NumberF.combinations(10, 3)\n    120.0","ref":"NumberF.html#combinations/2-examples","title":"Examples - NumberF.combinations/2","type":"function"},{"doc":"Formats a number into comma-separated format with the specified precision.","ref":"NumberF.html#comma_separated/2","title":"NumberF.comma_separated/2","type":"function"},{"doc":"- `number`: The number to format\n  - `precision`: Decimal places (default: 2)","ref":"NumberF.html#comma_separated/2-parameters","title":"Parameters - NumberF.comma_separated/2","type":"function"},{"doc":"iex> NumberF.comma_separated(1234567.89)\n    \"1,234,567.89\"\n\n    iex> NumberF.comma_separated(1234567.89, 0)\n    \"1,234,568\"\n\n    iex> NumberF.comma_separated(nil, 2)\n    nil","ref":"NumberF.html#comma_separated/2-examples","title":"Examples - NumberF.comma_separated/2","type":"function"},{"doc":"Calculates compound interest with optional compounding frequency.","ref":"NumberF.html#compound_interest/4","title":"NumberF.compound_interest/4","type":"function"},{"doc":"- Support for different compounding frequencies (annual, semi-annual, quarterly, monthly, etc.)\n- Precise calculations using Elixir's floating-point operations\n- Results rounded to 2 decimal places by default\n- Guard clauses ensure valid inputs","ref":"NumberF.html#compound_interest/4-features","title":"Features - NumberF.compound_interest/4","type":"function"},{"doc":"- `principal`: The principal amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `time`: The time period in years\n  - `frequency`: Number of times interest is compounded per year (default: 1)","ref":"NumberF.html#compound_interest/4-parameters","title":"Parameters - NumberF.compound_interest/4","type":"function"},{"doc":"iex> NumberF.compound_interest(1000, 0.05, 2)\n    102.5  # Annual compounding (1 time per year)\n\n    iex> NumberF.compound_interest(1000, 0.05, 2, 12)\n    104.94  # Monthly compounding (12 times per year)\n\n    iex> NumberF.compound_interest(10000, 0.08, 5, 4)\n    4693.28  # Quarterly compounding (4 times per year)","ref":"NumberF.html#compound_interest/4-examples","title":"Examples - NumberF.compound_interest/4","type":"function"},{"doc":"The compound interest is calculated using the formula:\n```\nA = P(1 + r/n)^(nt) - P\n```\nWhere:\n- A = Interest amount\n- P = Principal\n- r = Annual interest rate (decimal)\n- n = Compounding frequency\n- t = Time in years","ref":"NumberF.html#compound_interest/4-formula","title":"Formula - NumberF.compound_interest/4","type":"function"},{"doc":"- Investment calculations\n- Loan and mortgage analysis\n- Retirement planning\n- Financial education tools","ref":"NumberF.html#compound_interest/4-common-use-cases","title":"Common Use Cases - NumberF.compound_interest/4","type":"function"},{"doc":"- `NumberF.simple_interest/3`: Calculate simple interest\n- `NumberF.calculate_emi/3`: Calculate equated monthly installments\n- `NumberF.Tax.calculate_capital_gains_tax/3`: Calculate capital gains tax\n\nSee also: `NumberF.Financial` for more financial calculations.","ref":"NumberF.html#compound_interest/4-related-functions","title":"Related Functions - NumberF.compound_interest/4","type":"function"},{"doc":"Converts an amount between currencies based on exchange rates.","ref":"NumberF.html#convert_currency/3","title":"NumberF.convert_currency/3","type":"function"},{"doc":"- `amount`: The amount to convert\n  - `from_rate`: The exchange rate of the source currency\n  - `to_rate`: The exchange rate of the target currency","ref":"NumberF.html#convert_currency/3-parameters","title":"Parameters - NumberF.convert_currency/3","type":"function"},{"doc":"iex> NumberF.convert_currency(100, 1, 1.1)\n    110.0","ref":"NumberF.html#convert_currency/3-examples","title":"Examples - NumberF.convert_currency/3","type":"function"},{"doc":"Formats a number into currency with the specified unit and precision.","ref":"NumberF.html#currency/3","title":"NumberF.currency/3","type":"function"},{"doc":"- Automatic digit grouping with thousands separators\n- Configurable decimal precision\n- Support for custom currency symbols/codes\n- Consistent formatting for financial applications","ref":"NumberF.html#currency/3-features","title":"Features - NumberF.currency/3","type":"function"},{"doc":"- `number`: The number to format\n  - `unit`: The currency unit (default: \"ZMW\")\n  - `precision`: Decimal places (default: 2)","ref":"NumberF.html#currency/3-parameters","title":"Parameters - NumberF.currency/3","type":"function"},{"doc":"iex> NumberF.currency(1234.567)\n    \"ZMW 1,234.57\"\n\n    iex> NumberF.currency(1234.567, \"USD\", 2)\n    \"USD 1,234.57\"\n\n    iex> NumberF.currency(1234567.89, \"€\", 0)\n    \"€ 1,234,568\"\n\n    iex> NumberF.currency(nil, \"USD\", 2)\n    nil","ref":"NumberF.html#currency/3-examples","title":"Examples - NumberF.currency/3","type":"function"},{"doc":"- Financial reporting and analysis\n- E-commerce price displays\n- Invoice and receipt generation\n- Banking and financial applications","ref":"NumberF.html#currency/3-common-use-cases","title":"Common Use Cases - NumberF.currency/3","type":"function"},{"doc":"- `NumberF.comma_separated/2`: Format numbers with commas but no currency\n- `NumberF.format_currency/3`: Format with locale-specific currency settings\n- `NumberF.number_to_delimited/2`: Format with custom delimiters\n\nSee also: `NumberF.Currencies` for currency-specific information.","ref":"NumberF.html#currency/3-related-functions","title":"Related Functions - NumberF.currency/3","type":"function"},{"doc":"Returns a map of currency information with ISO codes, symbols, and formatting details.","ref":"NumberF.html#currency_data/0","title":"NumberF.currency_data/0","type":"function"},{"doc":"iex> NumberF.currency_data()[\"USD\"]\n    %{\n      name: \"US Dollar\",\n      symbol: \"$\",\n      symbol_first: true,\n      symbol_space: false,\n      decimal_places: 2,\n      thousands_separator: \",\",\n      decimal_separator: \".\"\n    }","ref":"NumberF.html#currency_data/0-examples","title":"Examples - NumberF.currency_data/0","type":"function"},{"doc":"Calculates the number of days between two dates.","ref":"NumberF.html#days_between/2","title":"NumberF.days_between/2","type":"function"},{"doc":"- `date1`: The first date\n  - `date2`: The second date","ref":"NumberF.html#days_between/2-parameters","title":"Parameters - NumberF.days_between/2","type":"function"},{"doc":"iex> NumberF.days_between(~D[2023-01-01], ~D[2023-01-10])\n    9","ref":"NumberF.html#days_between/2-examples","title":"Examples - NumberF.days_between/2","type":"function"},{"doc":"Generates a default password with pre-defined complexity.\nThe pattern is: capitalized 3-letter string + @ + 4 random digits.","ref":"NumberF.html#default_password/0","title":"NumberF.default_password/0","type":"function"},{"doc":"iex> NumberF.default_password()\n    \"Dev@2308\" # Example output, actual value will vary","ref":"NumberF.html#default_password/0-examples","title":"Examples - NumberF.default_password/0","type":"function"},{"doc":"Returns a markdown documentation of all NumberF modules and functions.","ref":"NumberF.html#documentation/0","title":"NumberF.documentation/0","type":"function"},{"doc":"iex> markdown = NumberF.documentation()\n    iex> String.starts_with?(markdown, \"# NumberF Library\")\n    true","ref":"NumberF.html#documentation/0-examples","title":"Examples - NumberF.documentation/0","type":"function"},{"doc":"Calculates the factorial of a non-negative integer.","ref":"NumberF.html#factorial/1","title":"NumberF.factorial/1","type":"function"},{"doc":"- `n`: The non-negative integer","ref":"NumberF.html#factorial/1-parameters","title":"Parameters - NumberF.factorial/1","type":"function"},{"doc":"iex> NumberF.factorial(5)\n    120\n\n    iex> NumberF.factorial(0)\n    1","ref":"NumberF.html#factorial/1-examples","title":"Examples - NumberF.factorial/1","type":"function"},{"doc":"Converts Fahrenheit to Celsius.","ref":"NumberF.html#fahrenheit_to_celsius/1","title":"NumberF.fahrenheit_to_celsius/1","type":"function"},{"doc":"- `fahrenheit`: The temperature in Fahrenheit","ref":"NumberF.html#fahrenheit_to_celsius/1-parameters","title":"Parameters - NumberF.fahrenheit_to_celsius/1","type":"function"},{"doc":"iex> NumberF.fahrenheit_to_celsius(32)\n    0.0\n\n    iex> NumberF.fahrenheit_to_celsius(212)\n    100.0","ref":"NumberF.html#fahrenheit_to_celsius/1-examples","title":"Examples - NumberF.fahrenheit_to_celsius/1","type":"function"},{"doc":"Formats a number as currency according to locale-specific settings.","ref":"NumberF.html#format_currency/3","title":"NumberF.format_currency/3","type":"function"},{"doc":"- Supports 100+ international locale formats\n- Proper positioning of currency symbols\n- Correct thousands and decimal separators for each locale\n- Configurable precision and currency code","ref":"NumberF.html#format_currency/3-features","title":"Features - NumberF.format_currency/3","type":"function"},{"doc":"- `number`: The number to format\n  - `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")\n  - `options`: Additional formatting options\n    - `:precision`: Number of decimal places (default: 2)\n    - `:currency_code`: ISO currency code to override the locale default\n    - `:symbol`: Whether to include the currency symbol (default: true)","ref":"NumberF.html#format_currency/3-parameters","title":"Parameters - NumberF.format_currency/3","type":"function"},{"doc":"iex> NumberF.format_currency(1234.56, \"en-US\")\n    \"$1,234.56\"\n\n    iex> NumberF.format_currency(1234.56, \"fr-FR\")\n    \"1 234,56 €\"\n\n    iex> NumberF.format_currency(1234.56, \"de-DE\", currency_code: \"USD\")\n    \"1.234,56 $\"\n\n    iex> NumberF.format_currency(1234.56, \"en-US\", symbol: false)\n    \"1,234.56\"","ref":"NumberF.html#format_currency/3-examples","title":"Examples - NumberF.format_currency/3","type":"function"},{"doc":"This function supports all major world locales including but not limited to:\nen-US, en-GB, fr-FR, de-DE, es-ES, it-IT, ja-JP, zh-CN, ru-RU, pt-BR, and many more.","ref":"NumberF.html#format_currency/3-supported-locales","title":"Supported Locales - NumberF.format_currency/3","type":"function"},{"doc":"- Multi-language applications\n- Financial applications with international users\n- E-commerce with global customers\n- Travel and currency conversion applications","ref":"NumberF.html#format_currency/3-common-use-cases","title":"Common Use Cases - NumberF.format_currency/3","type":"function"},{"doc":"- `NumberF.format_number/3`: Format without currency symbols\n- `NumberF.get_locale_settings/1`: Get formatting rules for a locale\n- `NumberF.spell_number/3`: Spell out numbers in different languages\n\nSee also: `NumberF.I18n` for more internationalization functions.","ref":"NumberF.html#format_currency/3-related-functions","title":"Related Functions - NumberF.format_currency/3","type":"function"},{"doc":"Formats a number according to locale-specific settings.","ref":"NumberF.html#format_number/3","title":"NumberF.format_number/3","type":"function"},{"doc":"- `number`: The number to format\n  - `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")\n  - `options`: Additional formatting options\n    - `:precision`: Number of decimal places (default: 2)","ref":"NumberF.html#format_number/3-parameters","title":"Parameters - NumberF.format_number/3","type":"function"},{"doc":"iex> NumberF.format_number(1234567.89, \"en-US\")\n    \"1,234,567.89\"\n\n    iex> NumberF.format_number(1234567.89, \"fr-FR\")\n    \"1 234 567,89\"","ref":"NumberF.html#format_number/3-examples","title":"Examples - NumberF.format_number/3","type":"function"},{"doc":"Formats phone numbers based on country code.","ref":"NumberF.html#format_phone/2","title":"NumberF.format_phone/2","type":"function"},{"doc":"- `number`: The phone number as a string\n  - `country_code`: The country code (default: \"ZM\" for Zambia)","ref":"NumberF.html#format_phone/2-parameters","title":"Parameters - NumberF.format_phone/2","type":"function"},{"doc":"iex> NumberF.format_phone(\"260977123456\", \"ZM\")\n    \"+260 97 712 3456\"\n\n    iex> NumberF.format_phone(\"14155552671\", \"US\")\n    \"+1 (415) 555-2671\"","ref":"NumberF.html#format_phone/2-examples","title":"Examples - NumberF.format_phone/2","type":"function"},{"doc":"Formats a currency with the specified currency code's rules.","ref":"NumberF.html#format_with_currency/3","title":"NumberF.format_with_currency/3","type":"function"},{"doc":"- `number`: The number to format\n  - `currency_code`: ISO currency code (e.g., \"USD\", \"EUR\")\n  - `options`: Additional options (override currency defaults)","ref":"NumberF.html#format_with_currency/3-parameters","title":"Parameters - NumberF.format_with_currency/3","type":"function"},{"doc":"iex> NumberF.format_with_currency(1234.56, \"USD\")\n    \"$1,234.56\"\n\n    iex> NumberF.format_with_currency(1234.56, \"EUR\")\n    \"1.234,56 €\"","ref":"NumberF.html#format_with_currency/3-examples","title":"Examples - NumberF.format_with_currency/3","type":"function"},{"doc":"Converts Roman numerals to Arabic numbers.","ref":"NumberF.html#from_roman/1","title":"NumberF.from_roman/1","type":"function"},{"doc":"- `roman`: The Roman numeral string","ref":"NumberF.html#from_roman/1-parameters","title":"Parameters - NumberF.from_roman/1","type":"function"},{"doc":"iex> NumberF.from_roman(\"IV\")\n    4\n\n    iex> NumberF.from_roman(\"XLII\")\n    42\n\n    iex> NumberF.from_roman(\"MCMXCIX\")\n    1999","ref":"NumberF.html#from_roman/1-examples","title":"Examples - NumberF.from_roman/1","type":"function"},{"doc":"Returns all function categories available in NumberF.","ref":"NumberF.html#function_categories/0","title":"NumberF.function_categories/0","type":"function"},{"doc":"iex> NumberF.function_categories() |> Enum.map(& &1.name) |> Enum.take(3)\n    [\"Formatting\", \"Conversion\", \"Generation\"]","ref":"NumberF.html#function_categories/0-examples","title":"Examples - NumberF.function_categories/0","type":"function"},{"doc":"Calculates the Greatest Common Divisor (GCD) of two integers.","ref":"NumberF.html#gcd/2","title":"NumberF.gcd/2","type":"function"},{"doc":"- `a`: First integer\n  - `b`: Second integer","ref":"NumberF.html#gcd/2-parameters","title":"Parameters - NumberF.gcd/2","type":"function"},{"doc":"iex> NumberF.gcd(48, 18)\n    6\n\n    iex> NumberF.gcd(7, 13)\n    1","ref":"NumberF.html#gcd/2-examples","title":"Examples - NumberF.gcd/2","type":"function"},{"doc":"Gets currency details for a specific currency code.","ref":"NumberF.html#get_currency/1","title":"NumberF.get_currency/1","type":"function"},{"doc":"- `currency_code`: ISO currency code (e.g., \"USD\", \"EUR\")","ref":"NumberF.html#get_currency/1-parameters","title":"Parameters - NumberF.get_currency/1","type":"function"},{"doc":"iex> NumberF.get_currency(\"USD\")\n    %{\n      name: \"US Dollar\",\n      symbol: \"$\",\n      symbol_first: true,\n      symbol_space: false,\n      decimal_places: 2,\n      thousands_separator: \",\",\n      decimal_separator: \".\"\n    }","ref":"NumberF.html#get_currency/1-examples","title":"Examples - NumberF.get_currency/1","type":"function"},{"doc":"Checks if a number is within a specified range (inclusive).","ref":"NumberF.html#in_range?/3","title":"NumberF.in_range?/3","type":"function"},{"doc":"- `value`: The number to check\n  - `min`: The minimum value of the range\n  - `max`: The maximum value of the range","ref":"NumberF.html#in_range?/3-parameters","title":"Parameters - NumberF.in_range?/3","type":"function"},{"doc":"iex> NumberF.in_range?(5, 1, 10)\n    true\n\n    iex> NumberF.in_range?(15, 1, 10)\n    false","ref":"NumberF.html#in_range?/3-examples","title":"Examples - NumberF.in_range?/3","type":"function"},{"doc":"Converts inches to centimeters.","ref":"NumberF.html#inches_to_cm/1","title":"NumberF.inches_to_cm/1","type":"function"},{"doc":"- `inches`: The length in inches","ref":"NumberF.html#inches_to_cm/1-parameters","title":"Parameters - NumberF.inches_to_cm/1","type":"function"},{"doc":"iex> NumberF.inches_to_cm(10)\n    25.4\n\n    iex> NumberF.inches_to_cm(3.5)\n    8.89","ref":"NumberF.html#inches_to_cm/1-examples","title":"Examples - NumberF.inches_to_cm/1","type":"function"},{"doc":"Performs a linear interpolation between two points.","ref":"NumberF.html#interpolate/5","title":"NumberF.interpolate/5","type":"function"},{"doc":"- `x`: The x value to interpolate at\n  - `x0`: The x coordinate of the first point\n  - `y0`: The y coordinate of the first point\n  - `x1`: The x coordinate of the second point\n  - `y1`: The y coordinate of the second point","ref":"NumberF.html#interpolate/5-parameters","title":"Parameters - NumberF.interpolate/5","type":"function"},{"doc":"iex> NumberF.interpolate(2.5, 2, 10, 3, 20)\n    15.0","ref":"NumberF.html#interpolate/5-examples","title":"Examples - NumberF.interpolate/5","type":"function"},{"doc":"Determines if a date is a business day.","ref":"NumberF.html#is_business_day?/1","title":"NumberF.is_business_day?/1","type":"function"},{"doc":"- `date`: The date to check","ref":"NumberF.html#is_business_day?/1-parameters","title":"Parameters - NumberF.is_business_day?/1","type":"function"},{"doc":"iex> NumberF.is_business_day?(~D[2023-01-02])\n    true\n\n    iex> NumberF.is_business_day?(~D[2023-01-01])\n    false","ref":"NumberF.html#is_business_day?/1-examples","title":"Examples - NumberF.is_business_day?/1","type":"function"},{"doc":"Checks if a number is prime.","ref":"NumberF.html#is_prime?/1","title":"NumberF.is_prime?/1","type":"function"},{"doc":"- `n`: The number to check","ref":"NumberF.html#is_prime?/1-parameters","title":"Parameters - NumberF.is_prime?/1","type":"function"},{"doc":"iex> NumberF.is_prime?(7)\n    true\n\n    iex> NumberF.is_prime?(6)\n    false","ref":"NumberF.html#is_prime?/1-examples","title":"Examples - NumberF.is_prime?/1","type":"function"},{"doc":"Validates credit card numbers using the Luhn algorithm.","ref":"NumberF.html#is_valid_credit_card?/2","title":"NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"- `number`: The credit card number as a string\n  - `type`: Card type to validate against (default: :any)\n    - Options: :any, :visa, :mastercard, :amex, :discover","ref":"NumberF.html#is_valid_credit_card?/2-parameters","title":"Parameters - NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"iex> NumberF.is_valid_credit_card?(\"4111111111111111\")\n    true\n\n    iex> NumberF.is_valid_credit_card?(\"4111111111111112\")\n    false","ref":"NumberF.html#is_valid_credit_card?/2-examples","title":"Examples - NumberF.is_valid_credit_card?/2","type":"function"},{"doc":"Checks if a string is a valid integer.","ref":"NumberF.html#is_valid_integer?/1","title":"NumberF.is_valid_integer?/1","type":"function"},{"doc":"- `str`: The string to check","ref":"NumberF.html#is_valid_integer?/1-parameters","title":"Parameters - NumberF.is_valid_integer?/1","type":"function"},{"doc":"iex> NumberF.is_valid_integer?(\"123\")\n    true\n\n    iex> NumberF.is_valid_integer?(\"123.45\")\n    false","ref":"NumberF.html#is_valid_integer?/1-examples","title":"Examples - NumberF.is_valid_integer?/1","type":"function"},{"doc":"Checks if a string is a valid number format.","ref":"NumberF.html#is_valid_number?/1","title":"NumberF.is_valid_number?/1","type":"function"},{"doc":"- `str`: The string to check","ref":"NumberF.html#is_valid_number?/1-parameters","title":"Parameters - NumberF.is_valid_number?/1","type":"function"},{"doc":"iex> NumberF.is_valid_number?(\"123\")\n    true\n\n    iex> NumberF.is_valid_number?(\"123.45\")\n    true\n\n    iex> NumberF.is_valid_number?(\"abc\")\n    false","ref":"NumberF.html#is_valid_number?/1-examples","title":"Examples - NumberF.is_valid_number?/1","type":"function"},{"doc":"Converts kilometers to miles.","ref":"NumberF.html#km_to_miles/1","title":"NumberF.km_to_miles/1","type":"function"},{"doc":"- `km`: The distance in kilometers","ref":"NumberF.html#km_to_miles/1-parameters","title":"Parameters - NumberF.km_to_miles/1","type":"function"},{"doc":"iex> NumberF.km_to_miles(16.09)\n    10.0","ref":"NumberF.html#km_to_miles/1-examples","title":"Examples - NumberF.km_to_miles/1","type":"function"},{"doc":"Calculates the Least Common Multiple (LCM) of two integers.","ref":"NumberF.html#lcm/2","title":"NumberF.lcm/2","type":"function"},{"doc":"- `a`: First integer\n  - `b`: Second integer","ref":"NumberF.html#lcm/2-parameters","title":"Parameters - NumberF.lcm/2","type":"function"},{"doc":"iex> NumberF.lcm(4, 6)\n    12\n\n    iex> NumberF.lcm(21, 6)\n    42","ref":"NumberF.html#lcm/2-examples","title":"Examples - NumberF.lcm/2","type":"function"},{"doc":"Calculates the arithmetic mean of a list of numbers.","ref":"NumberF.html#mean/1","title":"NumberF.mean/1","type":"function"},{"doc":"- Handles lists of any size\n- Returns nil for empty lists\n- Works with integers and floating-point numbers\n- Accurately calculates average using sum and count","ref":"NumberF.html#mean/1-features","title":"Features - NumberF.mean/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#mean/1-parameters","title":"Parameters - NumberF.mean/1","type":"function"},{"doc":"iex> NumberF.mean([1, 2, 3, 4, 5])\n    3.0\n\n    iex> NumberF.mean([1.5, 2.5, 3.5])\n    2.5\n\n    iex> NumberF.mean([42])\n    42.0\n\n    iex> NumberF.mean([])\n    nil","ref":"NumberF.html#mean/1-examples","title":"Examples - NumberF.mean/1","type":"function"},{"doc":"The arithmetic mean is the sum of all values divided by the number of values.","ref":"NumberF.html#mean/1-mathematical-definition","title":"Mathematical Definition - NumberF.mean/1","type":"function"},{"doc":"- Data analysis and statistics\n- Financial analysis (average returns, costs, etc.)\n- Scientific calculations\n- Performance metrics","ref":"NumberF.html#mean/1-common-use-cases","title":"Common Use Cases - NumberF.mean/1","type":"function"},{"doc":"- `NumberF.median/1`: Calculate the median value\n- `NumberF.mode/1`: Find the most frequent value(s)\n- `NumberF.standard_deviation/1`: Calculate standard deviation\n- `NumberF.variance/1`: Calculate variance\n\nSee also: `NumberF.Statistics` for more statistical functions.","ref":"NumberF.html#mean/1-related-functions","title":"Related Functions - NumberF.mean/1","type":"function"},{"doc":"Finds the median value from a list of numbers.","ref":"NumberF.html#median/1","title":"NumberF.median/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#median/1-parameters","title":"Parameters - NumberF.median/1","type":"function"},{"doc":"iex> NumberF.median([1, 3, 5, 7, 9])\n    5\n\n    iex> NumberF.median([1, 3, 5, 7])\n    4.0","ref":"NumberF.html#median/1-examples","title":"Examples - NumberF.median/1","type":"function"},{"doc":"Converts a memory size in bytes to a human-readable format.\nAutomatically selects the appropriate unit (B, KB, MB, GB) based on size.","ref":"NumberF.html#memory_size_cal/1","title":"NumberF.memory_size_cal/1","type":"function"},{"doc":"- `size`: The size in bytes","ref":"NumberF.html#memory_size_cal/1-parameters","title":"Parameters - NumberF.memory_size_cal/1","type":"function"},{"doc":"iex> NumberF.memory_size_cal(500)\n    \"500 B\"\n\n    iex> NumberF.memory_size_cal(1024)\n    \"1.0 KB\"\n\n    iex> NumberF.memory_size_cal(1048576)\n    \"1.0 MB\"\n\n    iex> NumberF.memory_size_cal(1073741824)\n    \"1.0 GB\"","ref":"NumberF.html#memory_size_cal/1-examples","title":"Examples - NumberF.memory_size_cal/1","type":"function"},{"doc":"Converts miles to kilometers.","ref":"NumberF.html#miles_to_km/1","title":"NumberF.miles_to_km/1","type":"function"},{"doc":"- `miles`: The distance in miles","ref":"NumberF.html#miles_to_km/1-parameters","title":"Parameters - NumberF.miles_to_km/1","type":"function"},{"doc":"iex> NumberF.miles_to_km(10)\n    16.09","ref":"NumberF.html#miles_to_km/1-examples","title":"Examples - NumberF.miles_to_km/1","type":"function"},{"doc":"Finds the most frequently occurring value(s) in a list.","ref":"NumberF.html#mode/1","title":"NumberF.mode/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#mode/1-parameters","title":"Parameters - NumberF.mode/1","type":"function"},{"doc":"iex> NumberF.mode([1, 2, 2, 3, 3, 3, 4])\n    [3]\n\n    iex> NumberF.mode([1, 1, 2, 2, 3])\n    [1, 2]","ref":"NumberF.html#mode/1-examples","title":"Examples - NumberF.mode/1","type":"function"},{"doc":"Returns information about all NumberF modules.","ref":"NumberF.html#modules/0","title":"NumberF.modules/0","type":"function"},{"doc":"iex> NumberF.modules() |> Enum.map(& &1.name) |> Enum.take(3)\n    [\"NumberF\", \"NumberF.Registry\", \"NumberF.Currency\"]","ref":"NumberF.html#modules/0-examples","title":"Examples - NumberF.modules/0","type":"function"},{"doc":"Returns information about NumberF modules of a specific type.","ref":"NumberF.html#modules_by_type/1","title":"NumberF.modules_by_type/1","type":"function"},{"doc":"- `type`: The module type (e.g., :formatting, :calculation)","ref":"NumberF.html#modules_by_type/1-parameters","title":"Parameters - NumberF.modules_by_type/1","type":"function"},{"doc":"iex> NumberF.modules_by_type(:formatting) |> Enum.map(& &1.name)\n    [\"NumberF.Currency\", \"NumberF.CustomFormatter\", \"NumberF.Formatter\", \"NumberF.Currencies\"]","ref":"NumberF.html#modules_by_type/1-examples","title":"Examples - NumberF.modules_by_type/1","type":"function"},{"doc":"Formats a number into a delimited format with options for customization.","ref":"NumberF.html#number_to_delimited/2","title":"NumberF.number_to_delimited/2","type":"function"},{"doc":"- `number`: The number to format\n  - `options`: Keyword options for formatting:\n    - `delimiter`: Character used as thousand delimiter (default: \",\")\n    - `separator`: Character used as decimal separator (default: \".\")\n    - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#number_to_delimited/2-parameters","title":"Parameters - NumberF.number_to_delimited/2","type":"function"},{"doc":"iex> NumberF.number_to_delimited(1234567.89)\n    \"1,234,567.89\"\n\n    iex> NumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\")\n    \"1.234.567,89\"\n\n    iex> NumberF.number_to_delimited(1234567.89, precision: 0)\n    \"1,234,568\"","ref":"NumberF.html#number_to_delimited/2-examples","title":"Examples - NumberF.number_to_delimited/2","type":"function"},{"doc":"Converts numbers to ordinals (1st, 2nd, 3rd, etc.).","ref":"NumberF.html#ordinal/1","title":"NumberF.ordinal/1","type":"function"},{"doc":"- `number`: The number to convert","ref":"NumberF.html#ordinal/1-parameters","title":"Parameters - NumberF.ordinal/1","type":"function"},{"doc":"iex> NumberF.ordinal(1)\n    \"1st\"\n\n    iex> NumberF.ordinal(2)\n    \"2nd\"\n\n    iex> NumberF.ordinal(3)\n    \"3rd\"\n\n    iex> NumberF.ordinal(4)\n    \"4th\"","ref":"NumberF.html#ordinal/1-examples","title":"Examples - NumberF.ordinal/1","type":"function"},{"doc":"Calculates payment due date based on invoice date and terms.","ref":"NumberF.html#payment_due_date/2","title":"NumberF.payment_due_date/2","type":"function"},{"doc":"- `invoice_date`: The invoice date as Date struct\n  - `terms_days`: Payment terms in days (default: 30)","ref":"NumberF.html#payment_due_date/2-parameters","title":"Parameters - NumberF.payment_due_date/2","type":"function"},{"doc":"iex> invoice_date = ~D[2023-01-15]\n    iex> NumberF.payment_due_date(invoice_date)\n    ~D[2023-02-14]\n\n    iex> invoice_date = ~D[2023-01-15]\n    iex> NumberF.payment_due_date(invoice_date, 45)\n    ~D[2023-03-01]","ref":"NumberF.html#payment_due_date/2-examples","title":"Examples - NumberF.payment_due_date/2","type":"function"},{"doc":"Calculates a percentage with specified precision.","ref":"NumberF.html#percentage/3","title":"NumberF.percentage/3","type":"function"},{"doc":"- `value`: The value to calculate percentage for\n  - `total`: The total value (100%)\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#percentage/3-parameters","title":"Parameters - NumberF.percentage/3","type":"function"},{"doc":"iex> NumberF.percentage(25, 100)\n    25.0\n\n    iex> NumberF.percentage(1, 3, 2)\n    33.33","ref":"NumberF.html#percentage/3-examples","title":"Examples - NumberF.percentage/3","type":"function"},{"doc":"Generates a random string of the specified length.","ref":"NumberF.html#randomizer/2","title":"NumberF.randomizer/2","type":"function"},{"doc":"- `length`: The length of the string\n  - `type`: Type of string, with options:\n    - `:all` (alphanumeric) - default\n    - `:alpha` (alphabetical)\n    - `:numeric` (numbers)\n    - `:upcase` (uppercase)\n    - `:downcase` (lowercase)","ref":"NumberF.html#randomizer/2-parameters","title":"Parameters - NumberF.randomizer/2","type":"function"},{"doc":"iex> NumberF.randomizer(10)\n    \"a1B2c3D4e5\" # Example output, actual value will vary\n\n    iex> NumberF.randomizer(5, :numeric)\n    \"23579\" # Example output, actual value will vary\n\n    iex> NumberF.randomizer(6, :upcase)\n    \"ABCDEF\" # Example output, actual value will vary","ref":"NumberF.html#randomizer/2-examples","title":"Examples - NumberF.randomizer/2","type":"function"},{"doc":"Calculates the range (difference between max and min values) of a dataset.","ref":"NumberF.html#range/1","title":"NumberF.range/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#range/1-parameters","title":"Parameters - NumberF.range/1","type":"function"},{"doc":"iex> NumberF.range([2, 4, 4, 4, 5, 5, 7, 9])\n    7.0","ref":"NumberF.html#range/1-examples","title":"Examples - NumberF.range/1","type":"function"},{"doc":"Returns all modules and their functions as a reference.\n\nThis function provides a comprehensive overview of all available functionality\nin the NumberF library, organized by module.","ref":"NumberF.html#reference/0","title":"NumberF.reference/0","type":"function"},{"doc":"iex> ref = NumberF.reference()\n    iex> is_map(ref)\n    true","ref":"NumberF.html#reference/0-examples","title":"Examples - NumberF.reference/0","type":"function"},{"doc":"Rounds a number to the nearest specified value.","ref":"NumberF.html#round_to_nearest/2","title":"NumberF.round_to_nearest/2","type":"function"},{"doc":"- `value`: The number to round\n  - `nearest`: The nearest value to round to (default: 1.0)","ref":"NumberF.html#round_to_nearest/2-parameters","title":"Parameters - NumberF.round_to_nearest/2","type":"function"},{"doc":"iex> NumberF.round_to_nearest(12.3)\n    12.0\n\n    iex> NumberF.round_to_nearest(12.3, 5)\n    10.0\n\n    iex> NumberF.round_to_nearest(12.3, 0.5)\n    12.5","ref":"NumberF.html#round_to_nearest/2-examples","title":"Examples - NumberF.round_to_nearest/2","type":"function"},{"doc":"Rounds a number to a specified number of decimal places.","ref":"NumberF.html#round_with_precision/2","title":"NumberF.round_with_precision/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.html#round_with_precision/2-parameters","title":"Parameters - NumberF.round_with_precision/2","type":"function"},{"doc":"iex> NumberF.round_with_precision(3.14159, 2)\n    3.14\n\n    iex> NumberF.round_with_precision(3.14159, 4)\n    3.1416","ref":"NumberF.html#round_with_precision/2-examples","title":"Examples - NumberF.round_with_precision/2","type":"function"},{"doc":"Calculates simple interest based on principal, rate and time.","ref":"NumberF.html#simple_interest/3","title":"NumberF.simple_interest/3","type":"function"},{"doc":"- `principal`: The principal amount\n  - `rate`: The annual interest rate as a decimal (e.g., 0.05 for 5%)\n  - `time`: The time period in years","ref":"NumberF.html#simple_interest/3-parameters","title":"Parameters - NumberF.simple_interest/3","type":"function"},{"doc":"iex> NumberF.simple_interest(1000, 0.05, 2)\n    100.0","ref":"NumberF.html#simple_interest/3-examples","title":"Examples - NumberF.simple_interest/3","type":"function"},{"doc":"Spells out a number in the specified language.","ref":"NumberF.html#spell_number/3","title":"NumberF.spell_number/3","type":"function"},{"doc":"- `number`: The number to spell out\n  - `language`: The language code (e.g., \"en\", \"fr\")\n  - `options`: Additional options\n    - `:capitalize`: Whether to capitalize the first letter (default: true)\n    - `:currency`: Whether to add currency names (default: false)\n    - `:currency_code`: ISO currency code (default: nil)","ref":"NumberF.html#spell_number/3-parameters","title":"Parameters - NumberF.spell_number/3","type":"function"},{"doc":"iex> NumberF.spell_number(42, \"en\")\n    \"Forty-two\"\n\n    iex> NumberF.spell_number(42, \"fr\")\n    \"Quarante-deux\"","ref":"NumberF.html#spell_number/3-examples","title":"Examples - NumberF.spell_number/3","type":"function"},{"doc":"Calculates standard deviation of a dataset.","ref":"NumberF.html#standard_deviation/1","title":"NumberF.standard_deviation/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#standard_deviation/1-parameters","title":"Parameters - NumberF.standard_deviation/1","type":"function"},{"doc":"iex> NumberF.standard_deviation([2, 4, 4, 4, 5, 5, 7, 9])\n    2.0","ref":"NumberF.html#standard_deviation/1-examples","title":"Examples - NumberF.standard_deviation/1","type":"function"},{"doc":"Sums a list of decimal numbers.","ref":"NumberF.html#sum_decimal/1","title":"NumberF.sum_decimal/1","type":"function"},{"doc":"- `list`: A list of decimal values, potentially nested","ref":"NumberF.html#sum_decimal/1-parameters","title":"Parameters - NumberF.sum_decimal/1","type":"function"},{"doc":"iex> sum_decimal([Decimal.new(\"1.2\"), Decimal.new(\"3.4\"), [Decimal.new(\"5.6\")]])\n    #Decimal<10.2>\n\n    iex> sum_decimal([])\n    #Decimal<0>\n\nThis function flattens any nested lists, then uses `Enum.reduce/3` to sum all the decimal values.","ref":"NumberF.html#sum_decimal/1-examples","title":"Examples - NumberF.sum_decimal/1","type":"function"},{"doc":"Converts a string to a boolean value.","ref":"NumberF.html#to_boolean/1","title":"NumberF.to_boolean/1","type":"function"},{"doc":"- `value`: The string value to convert. Accepts the following:\n    - `true`, `yes`, `on` convert to `true`\n    - `false`, `no`, `off` convert to `false`\n    - Any other value raises an ArgumentError","ref":"NumberF.html#to_boolean/1-parameters","title":"Parameters - NumberF.to_boolean/1","type":"function"},{"doc":"iex> NumberF.to_boolean(\"true\")\n    true\n\n    iex> NumberF.to_boolean(\"yes\")\n    true\n\n    iex> NumberF.to_boolean(\"false\")\n    false\n\n    iex> NumberF.to_boolean(\"no\")\n    false","ref":"NumberF.html#to_boolean/1-examples","title":"Examples - NumberF.to_boolean/1","type":"function"},{"doc":"Converts a value to a decimal.","ref":"NumberF.html#to_decimal/1","title":"NumberF.to_decimal/1","type":"function"},{"doc":"- `value`: The value to convert (string or number)","ref":"NumberF.html#to_decimal/1-parameters","title":"Parameters - NumberF.to_decimal/1","type":"function"},{"doc":"iex> NumberF.to_decimal(\"123.45\")\n    #Decimal<123.45>\n\n    iex> NumberF.to_decimal(123)\n    #Decimal<123>","ref":"NumberF.html#to_decimal/1-examples","title":"Examples - NumberF.to_decimal/1","type":"function"},{"doc":"Converts radians to degrees.","ref":"NumberF.html#to_degrees/1","title":"NumberF.to_degrees/1","type":"function"},{"doc":"- `radians`: The angle in radians","ref":"NumberF.html#to_degrees/1-parameters","title":"Parameters - NumberF.to_degrees/1","type":"function"},{"doc":"iex> NumberF.to_degrees(3.14159)\n    180.0","ref":"NumberF.html#to_degrees/1-examples","title":"Examples - NumberF.to_degrees/1","type":"function"},{"doc":"Converts a value to a float.","ref":"NumberF.html#to_float/1","title":"NumberF.to_float/1","type":"function"},{"doc":"- `value`: The value to convert (string or number)","ref":"NumberF.html#to_float/1-parameters","title":"Parameters - NumberF.to_float/1","type":"function"},{"doc":"iex> NumberF.to_float(\"123.45\")\n    123.45\n\n    iex> NumberF.to_float(123)\n    123.0","ref":"NumberF.html#to_float/1-examples","title":"Examples - NumberF.to_float/1","type":"function"},{"doc":"Converts a string to an integer.","ref":"NumberF.html#to_int/1","title":"NumberF.to_int/1","type":"function"},{"doc":"- `value`: The string value to convert","ref":"NumberF.html#to_int/1-parameters","title":"Parameters - NumberF.to_int/1","type":"function"},{"doc":"iex> NumberF.to_int(\"123\")\n    123\n\n    iex> NumberF.to_int(\"123.45\")\n    123","ref":"NumberF.html#to_int/1-examples","title":"Examples - NumberF.to_int/1","type":"function"},{"doc":"Converts degrees to radians.","ref":"NumberF.html#to_radians/1","title":"NumberF.to_radians/1","type":"function"},{"doc":"- `degrees`: The angle in degrees","ref":"NumberF.html#to_radians/1-parameters","title":"Parameters - NumberF.to_radians/1","type":"function"},{"doc":"iex> NumberF.to_radians(180)\n    3.141592653589793","ref":"NumberF.html#to_radians/1-examples","title":"Examples - NumberF.to_radians/1","type":"function"},{"doc":"Converts Arabic numbers to Roman numerals.","ref":"NumberF.html#to_roman/1","title":"NumberF.to_roman/1","type":"function"},{"doc":"- `number`: The number to convert (1-3999)","ref":"NumberF.html#to_roman/1-parameters","title":"Parameters - NumberF.to_roman/1","type":"function"},{"doc":"iex> NumberF.to_roman(4)\n    \"IV\"\n\n    iex> NumberF.to_roman(42)\n    \"XLII\"\n\n    iex> NumberF.to_roman(1999)\n    \"MCMXCIX\"","ref":"NumberF.html#to_roman/1-examples","title":"Examples - NumberF.to_roman/1","type":"function"},{"doc":"Converts a number into words with customizable currency terms.","ref":"NumberF.html#to_words/3","title":"NumberF.to_words/3","type":"function"},{"doc":"- Convert integers and decimals to their word representations\n- Support for custom currency terms for main and fractional units\n- Handles numbers from zero to trillions\n- Properly handles decimal values and zero cases","ref":"NumberF.html#to_words/3-features","title":"Features - NumberF.to_words/3","type":"function"},{"doc":"- `amount`: The number to convert\n  - `main_currency`: The main currency name (default: \"Kwacha\")\n  - `sec_currency`: The secondary currency name (default: \"Ngwee\")","ref":"NumberF.html#to_words/3-parameters","title":"Parameters - NumberF.to_words/3","type":"function"},{"doc":"iex> NumberF.to_words(20.0)\n    \"Twenty Kwacha and zero Ngwee\"\n\n    iex> NumberF.to_words(42.75, \"Dollars\", \"Cents\")\n    \"Forty Two Dollars And Seventy Five Cents\"\n\n    iex> NumberF.to_words(1234567.89, \"Euros\", \"Cents\")\n    \"One Million Two Hundred Thirty Four Thousand Five Hundred Sixty Seven Euros And Eighty Nine Cents\"\n\n    iex> NumberF.to_words(0, \"Euros\", \"Cents\")\n    \"zero Euros\"","ref":"NumberF.html#to_words/3-examples","title":"Examples - NumberF.to_words/3","type":"function"},{"doc":"- Check writing and financial documents\n- Legal documents requiring numeric values in words\n- Invoices and receipts\n- Educational applications","ref":"NumberF.html#to_words/3-common-use-cases","title":"Common Use Cases - NumberF.to_words/3","type":"function"},{"doc":"- `NumberF.spell_number/3`: Spell numbers in different languages\n- `NumberF.to_roman/1`: Convert to Roman numerals\n- `NumberF.ordinal/1`: Convert to ordinal forms (1st, 2nd, 3rd)\n\nSee also: `NumberF.NumbersToWords` for more advanced word conversion options.","ref":"NumberF.html#to_words/3-related-functions","title":"Related Functions - NumberF.to_words/3","type":"function"},{"doc":"Calculates the variance of a dataset.","ref":"NumberF.html#variance/1","title":"NumberF.variance/1","type":"function"},{"doc":"- `numbers`: A list of numbers","ref":"NumberF.html#variance/1-parameters","title":"Parameters - NumberF.variance/1","type":"function"},{"doc":"iex> NumberF.variance([2, 4, 4, 4, 5, 5, 7, 9])\n    4.0","ref":"NumberF.html#variance/1-examples","title":"Examples - NumberF.variance/1","type":"function"},{"doc":"Returns common VAT rates for different countries.","ref":"NumberF.html#vat_rates/0","title":"NumberF.vat_rates/0","type":"function"},{"doc":"iex> NumberF.vat_rates()[\"UK\"]\n    0.2\n\n    iex> NumberF.vat_rates()[\"Germany\"]\n    0.19","ref":"NumberF.html#vat_rates/0-examples","title":"Examples - NumberF.vat_rates/0","type":"function"},{"doc":"A registry of all NumberF modules and their functionality.\nUse this module to discover the available features and functions.","ref":"NumberF.Registry.html","title":"NumberF.Registry","type":"module"},{"doc":"Returns details about a specific function category.","ref":"NumberF.Registry.html#category_details/1","title":"NumberF.Registry.category_details/1","type":"function"},{"doc":"- `name`: The category name (e.g., \"Formatting\")","ref":"NumberF.Registry.html#category_details/1-parameters","title":"Parameters - NumberF.Registry.category_details/1","type":"function"},{"doc":"iex> NumberF.Registry.category_details(\"Formatting\")\n    %{\n      name: \"Formatting\",\n      description: \"Functions for formatting numbers in various ways\",\n      examples: [\"currency/3\", \"comma_separated/2\", \"number_to_delimited/2\", \"ordinal/1\"]\n    }","ref":"NumberF.Registry.html#category_details/1-examples","title":"Examples - NumberF.Registry.category_details/1","type":"function"},{"doc":"Returns a list of available function categories.","ref":"NumberF.Registry.html#function_categories/0","title":"NumberF.Registry.function_categories/0","type":"function"},{"doc":"Returns module details by name.","ref":"NumberF.Registry.html#module_details/1","title":"NumberF.Registry.module_details/1","type":"function"},{"doc":"- `name`: The module name (e.g., \"NumberF.Currency\")","ref":"NumberF.Registry.html#module_details/1-parameters","title":"Parameters - NumberF.Registry.module_details/1","type":"function"},{"doc":"iex> NumberF.Registry.module_details(\"NumberF.Currency\")\n    %{name: \"NumberF.Currency\", description: \"Currency formatting utilities\", type: :formatting}","ref":"NumberF.Registry.html#module_details/1-examples","title":"Examples - NumberF.Registry.module_details/1","type":"function"},{"doc":"Returns a list of all NumberF modules with brief descriptions.","ref":"NumberF.Registry.html#modules/0","title":"NumberF.Registry.modules/0","type":"function"},{"doc":"Returns a list of modules filtered by type.","ref":"NumberF.Registry.html#modules_by_type/1","title":"NumberF.Registry.modules_by_type/1","type":"function"},{"doc":"- `type`: The module type to filter by (e.g., :formatting, :calculation)","ref":"NumberF.Registry.html#modules_by_type/1-parameters","title":"Parameters - NumberF.Registry.modules_by_type/1","type":"function"},{"doc":"iex> NumberF.Registry.modules_by_type(:formatting)\n    [\n      %{name: \"NumberF.Currency\", description: \"Currency formatting utilities\", type: :formatting},\n      %{name: \"NumberF.CustomFormatter\", description: \"Custom implementation for number formatting\", type: :formatting},\n      %{name: \"NumberF.Formatter\", description: \"Number and data formatting utilities\", type: :formatting},\n      %{name: \"NumberF.Currencies\", description: \"Currency-specific utilities and data\", type: :formatting}\n    ]","ref":"NumberF.Registry.html#modules_by_type/1-examples","title":"Examples - NumberF.Registry.modules_by_type/1","type":"function"},{"doc":"Returns a markdown representation of all modules and their descriptions,\norganized by type.","ref":"NumberF.Registry.html#to_markdown/0","title":"NumberF.Registry.to_markdown/0","type":"function"},{"doc":"General numeric calculation functions.","ref":"NumberF.Calculations.html","title":"NumberF.Calculations","type":"module"},{"doc":"Calculates combinations (n choose k).","ref":"NumberF.Calculations.html#combinations/2","title":"NumberF.Calculations.combinations/2","type":"function"},{"doc":"Calculates factorial of a non-negative integer.","ref":"NumberF.Calculations.html#factorial/1","title":"NumberF.Calculations.factorial/1","type":"function"},{"doc":"Calculates the Greatest Common Divisor (GCD) of two integers.","ref":"NumberF.Calculations.html#gcd/2","title":"NumberF.Calculations.gcd/2","type":"function"},{"doc":"Checks if a number is within a specified range (inclusive).","ref":"NumberF.Calculations.html#in_range?/3","title":"NumberF.Calculations.in_range?/3","type":"function"},{"doc":"Performs a linear interpolation between two points.","ref":"NumberF.Calculations.html#interpolate/5","title":"NumberF.Calculations.interpolate/5","type":"function"},{"doc":"Checks if a number is prime.","ref":"NumberF.Calculations.html#is_prime?/1","title":"NumberF.Calculations.is_prime?/1","type":"function"},{"doc":"Calculates the Least Common Multiple (LCM) of two integers.","ref":"NumberF.Calculations.html#lcm/2","title":"NumberF.Calculations.lcm/2","type":"function"},{"doc":"Calculates a percentage with specified precision.","ref":"NumberF.Calculations.html#percentage/3","title":"NumberF.Calculations.percentage/3","type":"function"},{"doc":"Rounds a number to the nearest specified value.","ref":"NumberF.Calculations.html#round_to_nearest/2","title":"NumberF.Calculations.round_to_nearest/2","type":"function"},{"doc":"Converts radians to degrees.","ref":"NumberF.Calculations.html#to_degrees/1","title":"NumberF.Calculations.to_degrees/1","type":"function"},{"doc":"Converts degrees to radians.","ref":"NumberF.Calculations.html#to_radians/1","title":"NumberF.Calculations.to_radians/1","type":"function"},{"doc":"Functions for financial calculations such as interest, EMI, and currency conversion.","ref":"NumberF.Financial.html","title":"NumberF.Financial","type":"module"},{"doc":"Calculates EMI (Equated Monthly Installment).","ref":"NumberF.Financial.html#calculate_emi/3","title":"NumberF.Financial.calculate_emi/3","type":"function"},{"doc":"Calculates compound interest.","ref":"NumberF.Financial.html#compound_interest/4","title":"NumberF.Financial.compound_interest/4","type":"function"},{"doc":"Converts currency based on exchange rates.","ref":"NumberF.Financial.html#convert_currency/3","title":"NumberF.Financial.convert_currency/3","type":"function"},{"doc":"Calculates simple interest.","ref":"NumberF.Financial.html#simple_interest/3","title":"NumberF.Financial.simple_interest/3","type":"function"},{"doc":"Functions for handling numerical precision issues and implementing various rounding strategies.","ref":"NumberF.Precision.html","title":"NumberF.Precision","type":"module"},{"doc":"Checks if two floating point numbers are approximately equal.","ref":"NumberF.Precision.html#approximately_equal/3","title":"NumberF.Precision.approximately_equal/3","type":"function"},{"doc":"- `a`: First number\n  - `b`: Second number\n  - `epsilon`: Maximum allowed difference (default: 1.0e-10)","ref":"NumberF.Precision.html#approximately_equal/3-parameters","title":"Parameters - NumberF.Precision.approximately_equal/3","type":"function"},{"doc":"iex> NumberF.Precision.approximately_equal(0.1 + 0.2, 0.3)\n    true\n\n    iex> NumberF.Precision.approximately_equal(0.1, 0.2)\n    false","ref":"NumberF.Precision.html#approximately_equal/3-examples","title":"Examples - NumberF.Precision.approximately_equal/3","type":"function"},{"doc":"Rounds a number using banker's rounding (round to even).\nThis is more statistically unbiased than standard rounding.","ref":"NumberF.Precision.html#bankers_round/2","title":"NumberF.Precision.bankers_round/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#bankers_round/2-parameters","title":"Parameters - NumberF.Precision.bankers_round/2","type":"function"},{"doc":"iex> NumberF.Precision.bankers_round(2.5, 0)\n    2.0\n\n    iex> NumberF.Precision.bankers_round(3.5, 0)\n    4.0\n\n    iex> NumberF.Precision.bankers_round(2.125, 2)\n    2.12\n\n    iex> NumberF.Precision.bankers_round(2.135, 2)\n    2.14","ref":"NumberF.Precision.html#bankers_round/2-examples","title":"Examples - NumberF.Precision.bankers_round/2","type":"function"},{"doc":"Rounds a number up to a specified precision (ceiling).","ref":"NumberF.Precision.html#ceiling/2","title":"NumberF.Precision.ceiling/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#ceiling/2-parameters","title":"Parameters - NumberF.Precision.ceiling/2","type":"function"},{"doc":"iex> NumberF.Precision.ceiling(3.14159, 2)\n    3.15\n\n    iex> NumberF.Precision.ceiling(3.14159, 1)\n    3.2","ref":"NumberF.Precision.html#ceiling/2-examples","title":"Examples - NumberF.Precision.ceiling/2","type":"function"},{"doc":"Implements a custom rounding function with different modes.","ref":"NumberF.Precision.html#custom_round/3","title":"NumberF.Precision.custom_round/3","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places\n  - `mode`: Rounding mode (default: :half_up)\n    - :half_up - Round to nearest, 0.5 rounds up (standard)\n    - :half_down - Round to nearest, 0.5 rounds down\n    - :half_even - Round to nearest, 0.5 rounds to even (banker's)\n    - :ceiling - Always round up\n    - :floor - Always round down\n    - :truncate - Always truncate (toward zero)","ref":"NumberF.Precision.html#custom_round/3-parameters","title":"Parameters - NumberF.Precision.custom_round/3","type":"function"},{"doc":"iex> NumberF.Precision.custom_round(2.5, 0, :half_up)\n    3.0\n\n    iex> NumberF.Precision.custom_round(2.5, 0, :half_down)\n    2.0\n\n    iex> NumberF.Precision.custom_round(2.5, 0, :half_even)\n    2.0\n\n    iex> NumberF.Precision.custom_round(3.5, 0, :half_even)\n    4.0","ref":"NumberF.Precision.html#custom_round/3-examples","title":"Examples - NumberF.Precision.custom_round/3","type":"function"},{"doc":"Rounds a number down to a specified precision (floor).","ref":"NumberF.Precision.html#floor/2","title":"NumberF.Precision.floor/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#floor/2-parameters","title":"Parameters - NumberF.Precision.floor/2","type":"function"},{"doc":"iex> NumberF.Precision.floor(3.14159, 2)\n    3.14\n\n    iex> NumberF.Precision.floor(3.14159, 1)\n    3.1","ref":"NumberF.Precision.html#floor/2-examples","title":"Examples - NumberF.Precision.floor/2","type":"function"},{"doc":"Formats a number with a specified precision, using string manipulation\nto avoid floating-point rounding issues.","ref":"NumberF.Precision.html#precise_format/2","title":"NumberF.Precision.precise_format/2","type":"function"},{"doc":"- `number`: The number to format\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#precise_format/2-parameters","title":"Parameters - NumberF.Precision.precise_format/2","type":"function"},{"doc":"iex> NumberF.Precision.precise_format(3.14159, 2)\n    \"3.14\"\n\n    iex> NumberF.Precision.precise_format(3.14159, 4)\n    \"3.1416\"","ref":"NumberF.Precision.html#precise_format/2-examples","title":"Examples - NumberF.Precision.precise_format/2","type":"function"},{"doc":"Rounds a number to a specific increment.","ref":"NumberF.Precision.html#round_to/3","title":"NumberF.Precision.round_to/3","type":"function"},{"doc":"- `number`: The number to round\n  - `increment`: The increment to round to (default: 1.0)\n  - `strategy`: The rounding strategy (:nearest, :up, :down, or :bankers)","ref":"NumberF.Precision.html#round_to/3-parameters","title":"Parameters - NumberF.Precision.round_to/3","type":"function"},{"doc":"iex> NumberF.Precision.round_to(3.14159, 0.05, :nearest)\n    3.15\n\n    iex> NumberF.Precision.round_to(3.14159, 0.1, :up)\n    3.2\n\n    iex> NumberF.Precision.round_to(3.14159, 0.1, :down)\n    3.1","ref":"NumberF.Precision.html#round_to/3-examples","title":"Examples - NumberF.Precision.round_to/3","type":"function"},{"doc":"Rounds a number to a specified number of decimal places.","ref":"NumberF.Precision.html#round_with_precision/2","title":"NumberF.Precision.round_with_precision/2","type":"function"},{"doc":"- `number`: The number to round\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#round_with_precision/2-parameters","title":"Parameters - NumberF.Precision.round_with_precision/2","type":"function"},{"doc":"iex> NumberF.Precision.round_with_precision(3.14159, 2)\n    3.14\n\n    iex> NumberF.Precision.round_with_precision(3.14159, 4)\n    3.1416","ref":"NumberF.Precision.html#round_with_precision/2-examples","title":"Examples - NumberF.Precision.round_with_precision/2","type":"function"},{"doc":"Sanitizes a float value to handle special cases like NaN and Infinity.","ref":"NumberF.Precision.html#sanitize_float/2","title":"NumberF.Precision.sanitize_float/2","type":"function"},{"doc":"- `value`: The value to sanitize\n  - `default`: Default value to return for invalid numbers (default: 0.0)","ref":"NumberF.Precision.html#sanitize_float/2-parameters","title":"Parameters - NumberF.Precision.sanitize_float/2","type":"function"},{"doc":"iex> NumberF.Precision.sanitize_float(:nan, 0.0)\n    0.0\n\n    iex> NumberF.Precision.sanitize_float(:infinity, 0.0)\n    0.0\n\n    iex> NumberF.Precision.sanitize_float(3.14, 0.0)\n    3.14","ref":"NumberF.Precision.html#sanitize_float/2-examples","title":"Examples - NumberF.Precision.sanitize_float/2","type":"function"},{"doc":"Truncates a number to a specified precision (cuts off digits).","ref":"NumberF.Precision.html#truncate/2","title":"NumberF.Precision.truncate/2","type":"function"},{"doc":"- `number`: The number to truncate\n  - `precision`: Number of decimal places (default: 2)","ref":"NumberF.Precision.html#truncate/2-parameters","title":"Parameters - NumberF.Precision.truncate/2","type":"function"},{"doc":"iex> NumberF.Precision.truncate(3.14159, 2)\n    3.14\n\n    iex> NumberF.Precision.truncate(-3.14159, 2)\n    -3.14","ref":"NumberF.Precision.html#truncate/2-examples","title":"Examples - NumberF.Precision.truncate/2","type":"function"},{"doc":"Functions for statistical calculations and analysis of numerical data.","ref":"NumberF.Statistics.html","title":"NumberF.Statistics","type":"module"},{"doc":"Calculates the arithmetic mean of a list of numbers.","ref":"NumberF.Statistics.html#mean/1","title":"NumberF.Statistics.mean/1","type":"function"},{"doc":"Finds the median value from a list of numbers.","ref":"NumberF.Statistics.html#median/1","title":"NumberF.Statistics.median/1","type":"function"},{"doc":"Finds the most frequently occurring value(s) in a list.","ref":"NumberF.Statistics.html#mode/1","title":"NumberF.Statistics.mode/1","type":"function"},{"doc":"Calculates the range (difference between max and min values).","ref":"NumberF.Statistics.html#range/1","title":"NumberF.Statistics.range/1","type":"function"},{"doc":"Calculates standard deviation of a dataset.","ref":"NumberF.Statistics.html#standard_deviation/1","title":"NumberF.Statistics.standard_deviation/1","type":"function"},{"doc":"Calculates the variance of a dataset.","ref":"NumberF.Statistics.html#variance/1","title":"NumberF.Statistics.variance/1","type":"function"},{"doc":"Functions for tax calculations including VAT, sales tax, and income tax.","ref":"NumberF.Tax.html","title":"NumberF.Tax","type":"module"},{"doc":"Calculates tax on capital gains, with optional annual exemption.","ref":"NumberF.Tax.html#calculate_capital_gains_tax/3","title":"NumberF.Tax.calculate_capital_gains_tax/3","type":"function"},{"doc":"- `gain`: The capital gain amount\n  - `rate`: The capital gains tax rate as a decimal\n  - `exemption`: Annual tax-free allowance (default: 0)","ref":"NumberF.Tax.html#calculate_capital_gains_tax/3-parameters","title":"Parameters - NumberF.Tax.calculate_capital_gains_tax/3","type":"function"},{"doc":"iex> NumberF.Tax.calculate_capital_gains_tax(20000, 0.2, 12300)\n    %{gain: 20000.0, taxable_gain: 7700.0, tax: 1540.0, net: 18460.0}","ref":"NumberF.Tax.html#calculate_capital_gains_tax/3-examples","title":"Examples - NumberF.Tax.calculate_capital_gains_tax/3","type":"function"},{"doc":"Calculates corporate tax on profits.","ref":"NumberF.Tax.html#calculate_corporate_tax/2","title":"NumberF.Tax.calculate_corporate_tax/2","type":"function"},{"doc":"- `profit`: The taxable profit\n  - `rate`: The corporate tax rate as a decimal","ref":"NumberF.Tax.html#calculate_corporate_tax/2-parameters","title":"Parameters - NumberF.Tax.calculate_corporate_tax/2","type":"function"},{"doc":"iex> NumberF.Tax.calculate_corporate_tax(100000, 0.19)\n    %{profit: 100000.0, tax: 19000.0, after_tax: 81000.0}","ref":"NumberF.Tax.html#calculate_corporate_tax/2-examples","title":"Examples - NumberF.Tax.calculate_corporate_tax/2","type":"function"},{"doc":"Calculates progressive income tax based on tax brackets.","ref":"NumberF.Tax.html#calculate_income_tax/2","title":"NumberF.Tax.calculate_income_tax/2","type":"function"},{"doc":"- `income`: The taxable income\n  - `brackets`: A list of tax brackets, each as a tuple {threshold, rate}\n               sorted in ascending order by threshold","ref":"NumberF.Tax.html#calculate_income_tax/2-parameters","title":"Parameters - NumberF.Tax.calculate_income_tax/2","type":"function"},{"doc":"iex> brackets = [{0, 0.0}, {12570, 0.2}, {50270, 0.4}, {150000, 0.45}]\n    iex> NumberF.Tax.calculate_income_tax(30000, brackets)\n    %{tax: 3486.0, effective_rate: 0.1162}","ref":"NumberF.Tax.html#calculate_income_tax/2-examples","title":"Examples - NumberF.Tax.calculate_income_tax/2","type":"function"},{"doc":"Calculates payroll taxes including employee and employer contributions.","ref":"NumberF.Tax.html#calculate_payroll_tax/4","title":"NumberF.Tax.calculate_payroll_tax/4","type":"function"},{"doc":"- `salary`: The gross salary\n  - `employee_rate`: The employee contribution rate as a decimal\n  - `employer_rate`: The employer contribution rate as a decimal\n  - `cap`: Maximum amount subject to payroll tax (default: nil, no cap)","ref":"NumberF.Tax.html#calculate_payroll_tax/4-parameters","title":"Parameters - NumberF.Tax.calculate_payroll_tax/4","type":"function"},{"doc":"iex> NumberF.Tax.calculate_payroll_tax(50000, 0.12, 0.138)\n    %{salary: 50000.0, employee_contribution: 6000.0, employer_contribution: 6900.0, total_cost: 56900.0, take_home: 44000.0}","ref":"NumberF.Tax.html#calculate_payroll_tax/4-examples","title":"Examples - NumberF.Tax.calculate_payroll_tax/4","type":"function"},{"doc":"Calculates sales tax for a given amount and rate.","ref":"NumberF.Tax.html#calculate_sales_tax/3","title":"NumberF.Tax.calculate_sales_tax/3","type":"function"},{"doc":"- `amount`: The amount before tax\n  - `rate`: The sales tax rate as a decimal (e.g., 0.06 for 6%)\n  - `options`: Additional options\n    - `:round_to`: Round the tax amount to the nearest value (default: 0.01)","ref":"NumberF.Tax.html#calculate_sales_tax/3-parameters","title":"Parameters - NumberF.Tax.calculate_sales_tax/3","type":"function"},{"doc":"iex> NumberF.Tax.calculate_sales_tax(100, 0.06)\n    %{subtotal: 100.0, tax: 6.0, total: 106.0}\n\n    iex> NumberF.Tax.calculate_sales_tax(100, 0.06, round_to: 0.05)\n    %{subtotal: 100.0, tax: 6.0, total: 106.0}","ref":"NumberF.Tax.html#calculate_sales_tax/3-examples","title":"Examples - NumberF.Tax.calculate_sales_tax/3","type":"function"},{"doc":"Calculates Value Added Tax (VAT) for a given amount and rate.","ref":"NumberF.Tax.html#calculate_vat/3","title":"NumberF.Tax.calculate_vat/3","type":"function"},{"doc":"- `amount`: The amount before tax\n  - `rate`: The VAT rate as a decimal (e.g., 0.2 for 20%)\n  - `included`: Whether the amount already includes VAT (default: false)","ref":"NumberF.Tax.html#calculate_vat/3-parameters","title":"Parameters - NumberF.Tax.calculate_vat/3","type":"function"},{"doc":"iex> NumberF.Tax.calculate_vat(100, 0.2)\n    %{net: 100.0, vat: 20.0, gross: 120.0}\n\n    iex> NumberF.Tax.calculate_vat(120, 0.2, true)\n    %{net: 100.0, vat: 20.0, gross: 120.0}","ref":"NumberF.Tax.html#calculate_vat/3-examples","title":"Examples - NumberF.Tax.calculate_vat/3","type":"function"},{"doc":"Calculates withholding tax for dividends or interest based on a flat rate.","ref":"NumberF.Tax.html#calculate_withholding_tax/2","title":"NumberF.Tax.calculate_withholding_tax/2","type":"function"},{"doc":"- `amount`: The gross amount\n  - `rate`: The withholding tax rate as a decimal","ref":"NumberF.Tax.html#calculate_withholding_tax/2-parameters","title":"Parameters - NumberF.Tax.calculate_withholding_tax/2","type":"function"},{"doc":"iex> NumberF.Tax.calculate_withholding_tax(1000, 0.15)\n    %{gross: 1000.0, tax: 150.0, net: 850.0}","ref":"NumberF.Tax.html#calculate_withholding_tax/2-examples","title":"Examples - NumberF.Tax.calculate_withholding_tax/2","type":"function"},{"doc":"Returns sample income tax brackets for different countries.\nNote: These are simplified examples and may not reflect current tax law.","ref":"NumberF.Tax.html#income_tax_brackets/0","title":"NumberF.Tax.income_tax_brackets/0","type":"function"},{"doc":"iex> NumberF.Tax.income_tax_brackets()[\"US\"]\n    [{0, 0.1}, {9950, 0.12}, {40525, 0.22}, {86375, 0.24}, {164925, 0.32}, {209425, 0.35}, {523600, 0.37}]","ref":"NumberF.Tax.html#income_tax_brackets/0-examples","title":"Examples - NumberF.Tax.income_tax_brackets/0","type":"function"},{"doc":"Returns common VAT rates for different countries.","ref":"NumberF.Tax.html#vat_rates/0","title":"NumberF.Tax.vat_rates/0","type":"function"},{"doc":"iex> NumberF.Tax.vat_rates()[\"UK\"]\n    0.2\n\n    iex> NumberF.Tax.vat_rates()[\"Germany\"]\n    0.19","ref":"NumberF.Tax.html#vat_rates/0-examples","title":"Examples - NumberF.Tax.vat_rates/0","type":"function"},{"doc":"Functions and data for handling currency-specific operations and information.","ref":"NumberF.Currencies.html","title":"NumberF.Currencies","type":"module"},{"doc":"Converts an amount from one currency to another using exchange rates.","ref":"NumberF.Currencies.html#convert/5","title":"NumberF.Currencies.convert/5","type":"function"},{"doc":"- `amount`: The amount to convert\n  - `from_currency`: Source currency code\n  - `to_currency`: Target currency code\n  - `exchange_rates`: Map of exchange rates (relative to a base currency)\n  - `base_currency`: The base currency for the exchange rates (default: \"USD\")","ref":"NumberF.Currencies.html#convert/5-parameters","title":"Parameters - NumberF.Currencies.convert/5","type":"function"},{"doc":"iex> exchange_rates = %{\"USD\" => 1.0, \"EUR\" => 0.85, \"GBP\" => 0.75}\n    iex> NumberF.Currencies.convert(100, \"USD\", \"EUR\", exchange_rates)\n    85.0","ref":"NumberF.Currencies.html#convert/5-examples","title":"Examples - NumberF.Currencies.convert/5","type":"function"},{"doc":"Returns a map of currency information with ISO codes, symbols, and formatting details.","ref":"NumberF.Currencies.html#currency_data/0","title":"NumberF.Currencies.currency_data/0","type":"function"},{"doc":"Formats a number according to the currency's formatting rules.","ref":"NumberF.Currencies.html#format/3","title":"NumberF.Currencies.format/3","type":"function"},{"doc":"- `number`: The number to format\n  - `currency_code`: ISO currency code (e.g., \"USD\", \"EUR\")\n  - `options`: Additional formatting options (overrides defaults)","ref":"NumberF.Currencies.html#format/3-parameters","title":"Parameters - NumberF.Currencies.format/3","type":"function"},{"doc":"iex> NumberF.Currencies.format(1234.56, \"USD\")\n    \"$1,234.56\"\n\n    iex> NumberF.Currencies.format(1234.56, \"EUR\")\n    \"1.234,56 €\"\n\n    iex> NumberF.Currencies.format(1234.56, \"USD\", symbol: false)\n    \"1,234.56\"","ref":"NumberF.Currencies.html#format/3-examples","title":"Examples - NumberF.Currencies.format/3","type":"function"},{"doc":"Gets currency details for a specific currency code.","ref":"NumberF.Currencies.html#get_currency/1","title":"NumberF.Currencies.get_currency/1","type":"function"},{"doc":"- `currency_code`: ISO currency code (e.g., \"USD\", \"EUR\")","ref":"NumberF.Currencies.html#get_currency/1-parameters","title":"Parameters - NumberF.Currencies.get_currency/1","type":"function"},{"doc":"iex> NumberF.Currencies.get_currency(\"USD\")\n    %{\n      name: \"US Dollar\",\n      symbol: \"$\",\n      symbol_first: true,\n      symbol_space: false,\n      decimal_places: 2,\n      thousands_separator: \",\",\n      decimal_separator: \".\"\n    }","ref":"NumberF.Currencies.html#get_currency/1-examples","title":"Examples - NumberF.Currencies.get_currency/1","type":"function"},{"doc":"Parses a currency string into its numeric value.","ref":"NumberF.Currencies.html#parse/2","title":"NumberF.Currencies.parse/2","type":"function"},{"doc":"- `currency_string`: The currency string to parse\n  - `currency_code`: ISO currency code for formatting reference (optional)","ref":"NumberF.Currencies.html#parse/2-parameters","title":"Parameters - NumberF.Currencies.parse/2","type":"function"},{"doc":"iex> NumberF.Currencies.parse(\"$1,234.56\")\n    1234.56\n\n    iex> NumberF.Currencies.parse(\"1.234,56 €\", \"EUR\")\n    1234.56","ref":"NumberF.Currencies.html#parse/2-examples","title":"Examples - NumberF.Currencies.parse/2","type":"function"},{"doc":"Custom implementations for number formatting functions.\nReplaces functionality from the 'number' dependency.","ref":"NumberF.CustomFormatter.html","title":"NumberF.CustomFormatter","type":"module"},{"doc":"Formats a number as currency with specified unit and precision.","ref":"NumberF.CustomFormatter.html#number_to_currency/2","title":"NumberF.CustomFormatter.number_to_currency/2","type":"function"},{"doc":"iex> NumberF.CustomFormatter.number_to_currency(1234.56, unit: \"USD\", precision: 2)\n    \"USD 1,234.56\"\n\n    iex> NumberF.CustomFormatter.number_to_currency(\"1234.56\", unit: \"USD\", precision: 2)\n    \"USD 1,234.56\"","ref":"NumberF.CustomFormatter.html#number_to_currency/2-examples","title":"Examples - NumberF.CustomFormatter.number_to_currency/2","type":"function"},{"doc":"Formats a number with delimiters for thousands and decimal separator.","ref":"NumberF.CustomFormatter.html#number_to_delimited/2","title":"NumberF.CustomFormatter.number_to_delimited/2","type":"function"},{"doc":"iex> NumberF.CustomFormatter.number_to_delimited(1234567.89, delimiter: \",\", separator: \".\", precision: 2)\n    \"1,234,567.89\"\n\n    iex> NumberF.CustomFormatter.number_to_delimited(\"1234567.89\", delimiter: \",\", separator: \".\", precision: 2)\n    \"1,234,567.89\"","ref":"NumberF.CustomFormatter.html#number_to_delimited/2-examples","title":"Examples - NumberF.CustomFormatter.number_to_delimited/2","type":"function"},{"doc":"Converts a value to a Decimal.","ref":"NumberF.CustomFormatter.html#to_decimal/1","title":"NumberF.CustomFormatter.to_decimal/1","type":"function"},{"doc":"iex> NumberF.CustomFormatter.to_decimal(\"123.45\")\n    #Decimal<123.45>\n\n    iex> NumberF.CustomFormatter.to_decimal(123)\n    #Decimal<123>","ref":"NumberF.CustomFormatter.html#to_decimal/1-examples","title":"Examples - NumberF.CustomFormatter.to_decimal/1","type":"function"},{"doc":"Converts a value to a float.","ref":"NumberF.CustomFormatter.html#to_float/1","title":"NumberF.CustomFormatter.to_float/1","type":"function"},{"doc":"iex> NumberF.CustomFormatter.to_float(\"123.45\")\n    123.45\n\n    iex> NumberF.CustomFormatter.to_float(123)\n    123.0","ref":"NumberF.CustomFormatter.html#to_float/1-examples","title":"Examples - NumberF.CustomFormatter.to_float/1","type":"function"},{"doc":"Functions for formatting numbers and related data in various formats.","ref":"NumberF.Formatter.html","title":"NumberF.Formatter","type":"module"},{"doc":"Formats large numbers as K, M, B (e.g., 1.2K, 3.4M).","ref":"NumberF.Formatter.html#abbreviate_number/2","title":"NumberF.Formatter.abbreviate_number/2","type":"function"},{"doc":"Formats phone numbers based on country code.","ref":"NumberF.Formatter.html#format_phone/2","title":"NumberF.Formatter.format_phone/2","type":"function"},{"doc":"Converts Roman numerals to Arabic numbers.","ref":"NumberF.Formatter.html#from_roman/1","title":"NumberF.Formatter.from_roman/1","type":"function"},{"doc":"Converts numbers to ordinals (1st, 2nd, 3rd, etc.).","ref":"NumberF.Formatter.html#ordinal/1","title":"NumberF.Formatter.ordinal/1","type":"function"},{"doc":"Converts Arabic numbers to Roman numerals.","ref":"NumberF.Formatter.html#to_roman/1","title":"NumberF.Formatter.to_roman/1","type":"function"},{"doc":"Functions for handling unit conversions between different measurement systems.","ref":"NumberF.Metrics.html","title":"NumberF.Metrics","type":"module"},{"doc":"Converts acres to hectares.","ref":"NumberF.Metrics.html#acres_to_hectares/1","title":"NumberF.Metrics.acres_to_hectares/1","type":"function"},{"doc":"- `acres`: The area in acres","ref":"NumberF.Metrics.html#acres_to_hectares/1-parameters","title":"Parameters - NumberF.Metrics.acres_to_hectares/1","type":"function"},{"doc":"iex> NumberF.Metrics.acres_to_hectares(2.47)\n    1.0","ref":"NumberF.Metrics.html#acres_to_hectares/1-examples","title":"Examples - NumberF.Metrics.acres_to_hectares/1","type":"function"},{"doc":"","ref":"NumberF.Metrics.html#area_units/0","title":"NumberF.Metrics.area_units/0","type":"function"},{"doc":"Converts Celsius to Fahrenheit.","ref":"NumberF.Metrics.html#celsius_to_fahrenheit/1","title":"NumberF.Metrics.celsius_to_fahrenheit/1","type":"function"},{"doc":"- `celsius`: The temperature in Celsius","ref":"NumberF.Metrics.html#celsius_to_fahrenheit/1-parameters","title":"Parameters - NumberF.Metrics.celsius_to_fahrenheit/1","type":"function"},{"doc":"iex> NumberF.Metrics.celsius_to_fahrenheit(0)\n    32.0\n\n    iex> NumberF.Metrics.celsius_to_fahrenheit(100)\n    212.0","ref":"NumberF.Metrics.html#celsius_to_fahrenheit/1-examples","title":"Examples - NumberF.Metrics.celsius_to_fahrenheit/1","type":"function"},{"doc":"Converts centimeters to inches.","ref":"NumberF.Metrics.html#cm_to_inches/1","title":"NumberF.Metrics.cm_to_inches/1","type":"function"},{"doc":"- `cm`: The length in centimeters","ref":"NumberF.Metrics.html#cm_to_inches/1-parameters","title":"Parameters - NumberF.Metrics.cm_to_inches/1","type":"function"},{"doc":"iex> NumberF.Metrics.cm_to_inches(25.4)\n    10.0\n\n    iex> NumberF.Metrics.cm_to_inches(8.89)\n    3.5","ref":"NumberF.Metrics.html#cm_to_inches/1-examples","title":"Examples - NumberF.Metrics.cm_to_inches/1","type":"function"},{"doc":"Converts between different metric units of the same type.","ref":"NumberF.Metrics.html#convert_units/4","title":"NumberF.Metrics.convert_units/4","type":"function"},{"doc":"- `value`: The value to convert\n  - `from_unit`: The source unit\n  - `to_unit`: The target unit\n  - `conversion_map`: A map of conversion factors","ref":"NumberF.Metrics.html#convert_units/4-parameters","title":"Parameters - NumberF.Metrics.convert_units/4","type":"function"},{"doc":"iex> conversion_map = %{\n    ...>   \"mm\" => 0.001,\n    ...>   \"cm\" => 0.01,\n    ...>   \"m\" => 1,\n    ...>   \"km\" => 1000\n    ...> }\n    iex> NumberF.Metrics.convert_units(5, \"cm\", \"m\", conversion_map)\n    0.05","ref":"NumberF.Metrics.html#convert_units/4-examples","title":"Examples - NumberF.Metrics.convert_units/4","type":"function"},{"doc":"Converts Fahrenheit to Celsius.","ref":"NumberF.Metrics.html#fahrenheit_to_celsius/1","title":"NumberF.Metrics.fahrenheit_to_celsius/1","type":"function"},{"doc":"- `fahrenheit`: The temperature in Fahrenheit","ref":"NumberF.Metrics.html#fahrenheit_to_celsius/1-parameters","title":"Parameters - NumberF.Metrics.fahrenheit_to_celsius/1","type":"function"},{"doc":"iex> NumberF.Metrics.fahrenheit_to_celsius(32)\n    0.0\n\n    iex> NumberF.Metrics.fahrenheit_to_celsius(212)\n    100.0","ref":"NumberF.Metrics.html#fahrenheit_to_celsius/1-examples","title":"Examples - NumberF.Metrics.fahrenheit_to_celsius/1","type":"function"},{"doc":"Converts hectares to acres.","ref":"NumberF.Metrics.html#hectares_to_acres/1","title":"NumberF.Metrics.hectares_to_acres/1","type":"function"},{"doc":"- `hectares`: The area in hectares","ref":"NumberF.Metrics.html#hectares_to_acres/1-parameters","title":"Parameters - NumberF.Metrics.hectares_to_acres/1","type":"function"},{"doc":"iex> NumberF.Metrics.hectares_to_acres(1)\n    2.47","ref":"NumberF.Metrics.html#hectares_to_acres/1-examples","title":"Examples - NumberF.Metrics.hectares_to_acres/1","type":"function"},{"doc":"Converts inches to centimeters.","ref":"NumberF.Metrics.html#inches_to_cm/1","title":"NumberF.Metrics.inches_to_cm/1","type":"function"},{"doc":"- `inches`: The length in inches","ref":"NumberF.Metrics.html#inches_to_cm/1-parameters","title":"Parameters - NumberF.Metrics.inches_to_cm/1","type":"function"},{"doc":"iex> NumberF.Metrics.inches_to_cm(10)\n    25.4\n\n    iex> NumberF.Metrics.inches_to_cm(3.5)\n    8.89","ref":"NumberF.Metrics.html#inches_to_cm/1-examples","title":"Examples - NumberF.Metrics.inches_to_cm/1","type":"function"},{"doc":"Converts kilograms to pounds.","ref":"NumberF.Metrics.html#kg_to_pounds/1","title":"NumberF.Metrics.kg_to_pounds/1","type":"function"},{"doc":"- `kg`: The weight in kilograms","ref":"NumberF.Metrics.html#kg_to_pounds/1-parameters","title":"Parameters - NumberF.Metrics.kg_to_pounds/1","type":"function"},{"doc":"iex> NumberF.Metrics.kg_to_pounds(4.54)\n    10.01","ref":"NumberF.Metrics.html#kg_to_pounds/1-examples","title":"Examples - NumberF.Metrics.kg_to_pounds/1","type":"function"},{"doc":"Converts kilometers to miles.","ref":"NumberF.Metrics.html#km_to_miles/1","title":"NumberF.Metrics.km_to_miles/1","type":"function"},{"doc":"- `km`: The distance in kilometers","ref":"NumberF.Metrics.html#km_to_miles/1-parameters","title":"Parameters - NumberF.Metrics.km_to_miles/1","type":"function"},{"doc":"iex> NumberF.Metrics.km_to_miles(16.09)\n    10.0","ref":"NumberF.Metrics.html#km_to_miles/1-examples","title":"Examples - NumberF.Metrics.km_to_miles/1","type":"function"},{"doc":"","ref":"NumberF.Metrics.html#length_units/0","title":"NumberF.Metrics.length_units/0","type":"function"},{"doc":"Converts miles to kilometers.","ref":"NumberF.Metrics.html#miles_to_km/1","title":"NumberF.Metrics.miles_to_km/1","type":"function"},{"doc":"- `miles`: The distance in miles","ref":"NumberF.Metrics.html#miles_to_km/1-parameters","title":"Parameters - NumberF.Metrics.miles_to_km/1","type":"function"},{"doc":"iex> NumberF.Metrics.miles_to_km(10)\n    16.09","ref":"NumberF.Metrics.html#miles_to_km/1-examples","title":"Examples - NumberF.Metrics.miles_to_km/1","type":"function"},{"doc":"Converts milliliters to fluid ounces.","ref":"NumberF.Metrics.html#ml_to_oz/1","title":"NumberF.Metrics.ml_to_oz/1","type":"function"},{"doc":"- `ml`: The volume in milliliters","ref":"NumberF.Metrics.html#ml_to_oz/1-parameters","title":"Parameters - NumberF.Metrics.ml_to_oz/1","type":"function"},{"doc":"iex> NumberF.Metrics.ml_to_oz(29.57)\n    1.0","ref":"NumberF.Metrics.html#ml_to_oz/1-examples","title":"Examples - NumberF.Metrics.ml_to_oz/1","type":"function"},{"doc":"Converts fluid ounces to milliliters.","ref":"NumberF.Metrics.html#oz_to_ml/1","title":"NumberF.Metrics.oz_to_ml/1","type":"function"},{"doc":"- `oz`: The volume in fluid ounces","ref":"NumberF.Metrics.html#oz_to_ml/1-parameters","title":"Parameters - NumberF.Metrics.oz_to_ml/1","type":"function"},{"doc":"iex> NumberF.Metrics.oz_to_ml(1)\n    29.57","ref":"NumberF.Metrics.html#oz_to_ml/1-examples","title":"Examples - NumberF.Metrics.oz_to_ml/1","type":"function"},{"doc":"Converts pounds to kilograms.","ref":"NumberF.Metrics.html#pounds_to_kg/1","title":"NumberF.Metrics.pounds_to_kg/1","type":"function"},{"doc":"- `pounds`: The weight in pounds","ref":"NumberF.Metrics.html#pounds_to_kg/1-parameters","title":"Parameters - NumberF.Metrics.pounds_to_kg/1","type":"function"},{"doc":"iex> NumberF.Metrics.pounds_to_kg(10)\n    4.54","ref":"NumberF.Metrics.html#pounds_to_kg/1-examples","title":"Examples - NumberF.Metrics.pounds_to_kg/1","type":"function"},{"doc":"","ref":"NumberF.Metrics.html#volume_units/0","title":"NumberF.Metrics.volume_units/0","type":"function"},{"doc":"","ref":"NumberF.Metrics.html#weight_units/0","title":"NumberF.Metrics.weight_units/0","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html","title":"NumberF.NumberToWord","type":"module"},{"doc":"","ref":"NumberF.NumberToWord.html#format/4","title":"NumberF.NumberToWord.format/4","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#say/1","title":"NumberF.NumberToWord.say/1","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#say_io/1","title":"NumberF.NumberToWord.say_io/1","type":"function"},{"doc":"","ref":"NumberF.NumberToWord.html#separator/1","title":"NumberF.NumberToWord.separator/1","type":"function"},{"doc":"","ref":"NumberF.NumbersToWords.html","title":"NumberF.NumbersToWords","type":"module"},{"doc":"","ref":"NumberF.NumbersToWords.html#parse/3","title":"NumberF.NumbersToWords.parse/3","type":"function"},{"doc":"","ref":"NumberF.NumbersToWords.html#try/0","title":"NumberF.NumbersToWords.try/0","type":"function"},{"doc":"Functions for validating various numeric formats and related data.","ref":"NumberF.Validation.html","title":"NumberF.Validation","type":"module"},{"doc":"Validates credit card numbers using the Luhn algorithm.","ref":"NumberF.Validation.html#is_valid_credit_card?/2","title":"NumberF.Validation.is_valid_credit_card?/2","type":"function"},{"doc":"Checks if a string is a valid integer.","ref":"NumberF.Validation.html#is_valid_integer?/1","title":"NumberF.Validation.is_valid_integer?/1","type":"function"},{"doc":"Checks if a string is a valid number format.","ref":"NumberF.Validation.html#is_valid_number?/1","title":"NumberF.Validation.is_valid_number?/1","type":"function"},{"doc":"Functions for performing date-based calculations.","ref":"NumberF.DateCalculations.html","title":"NumberF.DateCalculations","type":"module"},{"doc":"Calculates the date after adding a specified number of business days.","ref":"NumberF.DateCalculations.html#add_business_days/2","title":"NumberF.DateCalculations.add_business_days/2","type":"function"},{"doc":"Calculates the number of business days between two dates.","ref":"NumberF.DateCalculations.html#business_days_between/2","title":"NumberF.DateCalculations.business_days_between/2","type":"function"},{"doc":"Calculates age based on birth date.","ref":"NumberF.DateCalculations.html#calculate_age/1","title":"NumberF.DateCalculations.calculate_age/1","type":"function"},{"doc":"Calculates the number of days between two dates.","ref":"NumberF.DateCalculations.html#days_between/2","title":"NumberF.DateCalculations.days_between/2","type":"function"},{"doc":"Determines if a date is a business day.","ref":"NumberF.DateCalculations.html#is_business_day?/1","title":"NumberF.DateCalculations.is_business_day?/1","type":"function"},{"doc":"Calculates the next business day after the given date.","ref":"NumberF.DateCalculations.html#next_business_day/1","title":"NumberF.DateCalculations.next_business_day/1","type":"function"},{"doc":"Calculates payment due date based on invoice date and terms.","ref":"NumberF.DateCalculations.html#payment_due_date/2","title":"NumberF.DateCalculations.payment_due_date/2","type":"function"},{"doc":"Functions for number internationalization and localization.","ref":"NumberF.I18n.html","title":"NumberF.I18n","type":"module"},{"doc":"Formats a number as currency according to locale-specific settings.","ref":"NumberF.I18n.html#format_currency/3","title":"NumberF.I18n.format_currency/3","type":"function"},{"doc":"- `number`: The number to format\n  - `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")\n  - `options`: Additional formatting options\n    - `:precision`: Number of decimal places (default: 2)\n    - `:currency_code`: ISO currency code to override the locale default\n    - `:symbol`: Whether to include the currency symbol (default: true)","ref":"NumberF.I18n.html#format_currency/3-parameters","title":"Parameters - NumberF.I18n.format_currency/3","type":"function"},{"doc":"iex> NumberF.I18n.format_currency(1234.56, \"en-US\")\n    \"$1,234.56\"\n\n    iex> NumberF.I18n.format_currency(1234.56, \"fr-FR\")\n    \"1 234,56 €\"\n\n    iex> NumberF.I18n.format_currency(1234.56, \"en-US\", currency_code: \"EUR\")\n    \"€1,234.56\"","ref":"NumberF.I18n.html#format_currency/3-examples","title":"Examples - NumberF.I18n.format_currency/3","type":"function"},{"doc":"Formats a number according to locale-specific settings.","ref":"NumberF.I18n.html#format_number/3","title":"NumberF.I18n.format_number/3","type":"function"},{"doc":"- `number`: The number to format\n  - `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")\n  - `options`: Additional formatting options\n    - `:precision`: Number of decimal places (default: 2)","ref":"NumberF.I18n.html#format_number/3-parameters","title":"Parameters - NumberF.I18n.format_number/3","type":"function"},{"doc":"iex> NumberF.I18n.format_number(1234567.89, \"en-US\")\n    \"1,234,567.89\"\n\n    iex> NumberF.I18n.format_number(1234567.89, \"fr-FR\")\n    \"1 234 567,89\"\n\n    iex> NumberF.I18n.format_number(1234567.89, \"de-DE\", precision: 3)\n    \"1.234.567,890\"","ref":"NumberF.I18n.html#format_number/3-examples","title":"Examples - NumberF.I18n.format_number/3","type":"function"},{"doc":"Returns currency names for different languages.","ref":"NumberF.I18n.html#get_currency_names/2","title":"NumberF.I18n.get_currency_names/2","type":"function"},{"doc":"- `currency_code`: ISO currency code\n  - `language`: Language code","ref":"NumberF.I18n.html#get_currency_names/2-parameters","title":"Parameters - NumberF.I18n.get_currency_names/2","type":"function"},{"doc":"iex> NumberF.I18n.get_currency_names(\"USD\", \"en\")\n    %{main: \"dollars\", sub: \"cents\"}\n\n    iex> NumberF.I18n.get_currency_names(\"EUR\", \"fr\")\n    %{main: \"euros\", sub: \"centimes\"}","ref":"NumberF.I18n.html#get_currency_names/2-examples","title":"Examples - NumberF.I18n.get_currency_names/2","type":"function"},{"doc":"Returns locale-specific number formatting settings.","ref":"NumberF.I18n.html#get_locale_settings/1","title":"NumberF.I18n.get_locale_settings/1","type":"function"},{"doc":"- `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")","ref":"NumberF.I18n.html#get_locale_settings/1-parameters","title":"Parameters - NumberF.I18n.get_locale_settings/1","type":"function"},{"doc":"iex> NumberF.I18n.get_locale_settings(\"en-US\")\n    %{\n      thousands_separator: \",\",\n      decimal_separator: \".\",\n      currency_symbol: \"$\",\n      currency_symbol_first: true\n    }\n\n    iex> NumberF.I18n.get_locale_settings(\"fr-FR\")\n    %{\n      thousands_separator: \" \",\n      decimal_separator: \",\",\n      currency_symbol: \"€\",\n      currency_symbol_first: false\n    }","ref":"NumberF.I18n.html#get_locale_settings/1-examples","title":"Examples - NumberF.I18n.get_locale_settings/1","type":"function"},{"doc":"Parses a localized number string into a floating-point value.","ref":"NumberF.I18n.html#parse_number/2","title":"NumberF.I18n.parse_number/2","type":"function"},{"doc":"- `number_string`: The string to parse\n  - `locale`: The locale code (e.g., \"en-US\", \"fr-FR\")","ref":"NumberF.I18n.html#parse_number/2-parameters","title":"Parameters - NumberF.I18n.parse_number/2","type":"function"},{"doc":"iex> NumberF.I18n.parse_number(\"1,234.56\", \"en-US\")\n    1234.56\n\n    iex> NumberF.I18n.parse_number(\"1 234,56\", \"fr-FR\")\n    1234.56","ref":"NumberF.I18n.html#parse_number/2-examples","title":"Examples - NumberF.I18n.parse_number/2","type":"function"},{"doc":"Spells out a number in the specified language.","ref":"NumberF.I18n.html#spell_number/3","title":"NumberF.I18n.spell_number/3","type":"function"},{"doc":"- `number`: The number to spell out\n  - `language`: The language code (e.g., \"en\", \"fr\")\n  - `options`: Additional options\n    - `:capitalize`: Whether to capitalize the first letter (default: true)\n    - `:currency`: Whether to add currency names (default: false)\n    - `:currency_code`: ISO currency code (default: nil)","ref":"NumberF.I18n.html#spell_number/3-parameters","title":"Parameters - NumberF.I18n.spell_number/3","type":"function"},{"doc":"iex> NumberF.I18n.spell_number(42, \"en\")\n    \"Forty-two\"\n\n    iex> NumberF.I18n.spell_number(42, \"fr\")\n    \"Quarante-deux\"\n\n    iex> NumberF.I18n.spell_number(42.75, \"en\", currency: true, currency_code: \"USD\")\n    \"Forty-two dollars and seventy-five cents\"","ref":"NumberF.I18n.html#spell_number/3-examples","title":"Examples - NumberF.I18n.spell_number/3","type":"function"},{"doc":"# Getting Started with NumberF\n\nNumberF is a powerful utility library for Elixir that makes working with numbers easy and intuitive. This guide will help you get started with the most common features.","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"Add `number_f` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:number_f, \"~> 0.1.6\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation","title":"Installation - Overview","type":"extras"},{"doc":"Once installed, you can start using NumberF's functionality by importing or accessing it directly:\n\n```elixir\n# In your module\ndefmodule MyApp.SomeModule do\n  # You can use NumberF functions directly\n  def format_price(price) do\n    NumberF.currency(price, \"USD\")\n  end\nend\n```","ref":"readme.html#basic-usage","title":"Basic Usage - Overview","type":"extras"},{"doc":"","ref":"readme.html#core-feature-areas","title":"Core Feature Areas - Overview","type":"extras"},{"doc":"```elixir\n# Format as currency\nNumberF.currency(1234.567)                    # => \"ZMW 1,234.57\"\nNumberF.currency(1234.567, \"USD\", 2)          # => \"USD 1,234.57\"\n\n# Format with commas\nNumberF.comma_separated(1234567.89)           # => \"1,234,567.89\"\n\n# Custom delimiters\nNumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\") # => \"1.234.567,89\"\n```","ref":"readme.html#1-number-formatting","title":"1. Number Formatting - Overview","type":"extras"},{"doc":"```elixir\n# Convert numbers to words\nNumberF.to_words(20.0)                        # => \"Twenty Kwacha and zero Ngwee\"\nNumberF.to_words(42.75, \"Dollars\", \"Cents\")   # => \"Forty Two Dollars And Seventy Five Cents\"\n\n# Roman numerals\nNumberF.to_roman(1999)                        # => \"MCMXCIX\"\nNumberF.from_roman(\"MCMXCIX\")                 # => 1999\n\n# Ordinals\nNumberF.ordinal(21)                           # => \"21st\"\n```","ref":"readme.html#2-number-to-text-conversion","title":"2. Number to Text Conversion - Overview","type":"extras"},{"doc":"```elixir\n# Simple interest\nNumberF.simple_interest(1000, 0.05, 2)        # => 100.0\n\n# Compound interest\nNumberF.compound_interest(1000, 0.05, 2)      # => 102.5\nNumberF.compound_interest(1000, 0.05, 2, 12)  # => 104.94 (monthly compounding)\n\n# EMI calculation\nNumberF.calculate_emi(100000, 0.10, 12)       # => 8791.59\n```","ref":"readme.html#3-financial-calculations","title":"3. Financial Calculations - Overview","type":"extras"},{"doc":"```elixir\n# Basic statistics\nNumberF.mean([1, 2, 3, 4, 5])                # => 3.0\nNumberF.median([1, 3, 5, 7, 9])              # => 5\nNumberF.mode([1, 2, 2, 3, 3, 3, 4])          # => [3]\nNumberF.standard_deviation([2, 4, 4, 4, 5, 5, 7, 9])  # => 2.0\n```","ref":"readme.html#4-statistical-functions","title":"4. Statistical Functions - Overview","type":"extras"},{"doc":"```elixir\n# Format with locale\nNumberF.format_number(1234567.89, \"en-US\")           # => \"1,234,567.89\"\nNumberF.format_number(1234567.89, \"fr-FR\")           # => \"1 234 567,89\"\n\n# Currency with locale\nNumberF.format_currency(1234.56, \"en-US\")            # => \"$1,234.56\"\nNumberF.format_currency(1234.56, \"fr-FR\")            # => \"1 234,56 €\"\n```","ref":"readme.html#5-internationalization","title":"5. Internationalization - Overview","type":"extras"},{"doc":"NumberF includes many advanced features for specialized use cases:\n\n- Tax calculations (VAT, sales tax, income tax)\n- Precision handling with multiple rounding strategies\n- Unit conversion between metric and imperial\n- Date calculations (business days, payment terms)\n- Phone number formatting\n- Credit card validation\n- Memory size humanization\n\nCheck the module-specific documentation for details on these advanced features.","ref":"readme.html#advanced-features","title":"Advanced Features - Overview","type":"extras"},{"doc":"If you need help with NumberF, you can:\n\n1. Read the [full documentation on HexDocs](https://hexdocs.pm/number_f)\n2. Open an issue if you encounter a problem or have a feature request\n\nWe hope NumberF makes your Elixir development experience more enjoyable!","ref":"readme.html#getting-help","title":"Getting Help - Overview","type":"extras"},{"doc":"# Getting Started with NumberF\n\nNumberF is a powerful utility library for Elixir that makes working with numbers easy and intuitive. This guide will help you get started with the most common features.","ref":"getting-started.html","title":"Getting Started","type":"extras"},{"doc":"Add `number_f` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:number_f, \"~> 0.1.5\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"getting-started.html#installation","title":"Installation - Getting Started","type":"extras"},{"doc":"Once installed, you can start using NumberF's functionality by importing or accessing it directly:\n\n```elixir\n# In your module\ndefmodule MyApp.SomeModule do\n  # You can use NumberF functions directly\n  def format_price(price) do\n    NumberF.currency(price, \"USD\")\n  end\nend\n```","ref":"getting-started.html#basic-usage","title":"Basic Usage - Getting Started","type":"extras"},{"doc":"","ref":"getting-started.html#core-feature-areas","title":"Core Feature Areas - Getting Started","type":"extras"},{"doc":"```elixir\n# Format as currency\nNumberF.currency(1234.567)                    # => \"ZMW 1,234.57\"\nNumberF.currency(1234.567, \"USD\", 2)          # => \"USD 1,234.57\"\n\n# Format with commas\nNumberF.comma_separated(1234567.89)           # => \"1,234,567.89\"\n\n# Custom delimiters\nNumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\") # => \"1.234.567,89\"\n```","ref":"getting-started.html#1-number-formatting","title":"1. Number Formatting - Getting Started","type":"extras"},{"doc":"```elixir\n# Convert numbers to words\nNumberF.to_words(20.0)                        # => \"Twenty Kwacha and zero Ngwee\"\nNumberF.to_words(42.75, \"Dollars\", \"Cents\")   # => \"Forty Two Dollars And Seventy Five Cents\"\n\n# Roman numerals\nNumberF.to_roman(1999)                        # => \"MCMXCIX\"\nNumberF.from_roman(\"MCMXCIX\")                 # => 1999\n\n# Ordinals\nNumberF.ordinal(21)                           # => \"21st\"\n```","ref":"getting-started.html#2-number-to-text-conversion","title":"2. Number to Text Conversion - Getting Started","type":"extras"},{"doc":"```elixir\n# Simple interest\nNumberF.simple_interest(1000, 0.05, 2)        # => 100.0\n\n# Compound interest\nNumberF.compound_interest(1000, 0.05, 2)      # => 102.5\nNumberF.compound_interest(1000, 0.05, 2, 12)  # => 104.94 (monthly compounding)\n\n# EMI calculation\nNumberF.calculate_emi(100000, 0.10, 12)       # => 8791.59\n```","ref":"getting-started.html#3-financial-calculations","title":"3. Financial Calculations - Getting Started","type":"extras"},{"doc":"```elixir\n# Basic statistics\nNumberF.mean([1, 2, 3, 4, 5])                # => 3.0\nNumberF.median([1, 3, 5, 7, 9])              # => 5\nNumberF.mode([1, 2, 2, 3, 3, 3, 4])          # => [3]\nNumberF.standard_deviation([2, 4, 4, 4, 5, 5, 7, 9])  # => 2.0\n```","ref":"getting-started.html#4-statistical-functions","title":"4. Statistical Functions - Getting Started","type":"extras"},{"doc":"```elixir\n# Format with locale\nNumberF.format_number(1234567.89, \"en-US\")           # => \"1,234,567.89\"\nNumberF.format_number(1234567.89, \"fr-FR\")           # => \"1 234 567,89\"\n\n# Currency with locale\nNumberF.format_currency(1234.56, \"en-US\")            # => \"$1,234.56\"\nNumberF.format_currency(1234.56, \"fr-FR\")            # => \"1 234,56 €\"\n```","ref":"getting-started.html#5-internationalization","title":"5. Internationalization - Getting Started","type":"extras"},{"doc":"NumberF includes many advanced features for specialized use cases:\n\n- Tax calculations (VAT, sales tax, income tax)\n- Precision handling with multiple rounding strategies\n- Unit conversion between metric and imperial\n- Date calculations (business days, payment terms)\n- Phone number formatting\n- Credit card validation\n- Memory size humanization\n\nCheck the module-specific documentation for details on these advanced features.","ref":"getting-started.html#advanced-features","title":"Advanced Features - Getting Started","type":"extras"},{"doc":"If you need help with NumberF, you can:\n\n1. Read the [full documentation on HexDocs](https://hexdocs.pm/number_f)\n2. Visit the [GitHub repository](https://github.com/jamesnjovu/elixir_number_functions)\n3. Open an issue if you encounter a problem or have a feature request\n\nWe hope NumberF makes your Elixir development experience more enjoyable!","ref":"getting-started.html#getting-help","title":"Getting Help - Getting Started","type":"extras"},{"doc":"# Currency Formatting with NumberF\n\nThis guide covers the comprehensive currency formatting capabilities in NumberF, designed to make financial applications easier to build and maintain.","ref":"currency-formatting.html","title":"Currency Formatting","type":"extras"},{"doc":"The `currency/3` function is the most common way to format numbers as currency:\n\n```elixir\nNumberF.currency(1234.567)                    # => \"ZMW 1,234.57\"\nNumberF.currency(1234.567, \"USD\", 2)          # => \"USD 1,234.57\"\nNumberF.currency(1234.567, \"$\", 2)            # => \"$ 1,234.57\"\n```\n\nThe function takes three parameters:\n- `number`: The number to format\n- `unit`: The currency unit (default: \"ZMW\")\n- `precision`: Decimal places (default: 2)","ref":"currency-formatting.html#basic-currency-formatting","title":"Basic Currency Formatting - Currency Formatting","type":"extras"},{"doc":"For more sophisticated currency formatting that respects locale conventions, use the `format_currency/3` function:\n\n```elixir\n# US Dollar format\nNumberF.format_currency(1234.56, \"en-US\")  \n# => \"$1,234.56\"\n\n# Euro format in French locale\nNumberF.format_currency(1234.56, \"fr-FR\")  \n# => \"1 234,56 €\"\n\n# British Pound format\nNumberF.format_currency(1234.56, \"en-GB\")  \n# => \"£1,234.56\"\n\n# Japanese Yen format\nNumberF.format_currency(1234.56, \"ja-JP\")  \n# => \"¥1,235\"  (Yen typically has 0 decimal places)\n\n# Using a different currency than the locale default\nNumberF.format_currency(1234.56, \"de-DE\", currency_code: \"USD\")  \n# => \"1.234,56 $\"\n```\n\nThis function handles:\n- Correct decimal and thousands separators for each locale\n- Proper currency symbol placement (before or after the number)\n- Appropriate spacing between symbol and number\n- Default decimal places for each currency","ref":"currency-formatting.html#advanced-currency-formatting-with-locales","title":"Advanced Currency Formatting with Locales - Currency Formatting","type":"extras"},{"doc":"For complete control over currency formatting, use `number_to_delimited/2`:\n\n```elixir\n# European style with period as thousands separator and comma as decimal\nNumberF.number_to_delimited(1234567.89, delimiter: \".\", separator: \",\")  \n# => \"1.234.567,89\"\n\n# No thousands separator\nNumberF.number_to_delimited(1234567.89, delimiter: \"\", separator: \".\")  \n# => \"1234567.89\"\n\n# Custom precision\nNumberF.number_to_delimited(1234567.89, precision: 3)  \n# => \"1,234,567.890\"\n```","ref":"currency-formatting.html#custom-currency-formatting","title":"Custom Currency Formatting - Currency Formatting","type":"extras"},{"doc":"For compact display of large currency values:\n\n```elixir\nNumberF.abbreviate_number(1234)               # => \"1.2K\"\nNumberF.abbreviate_number(1234567)            # => \"1.2M\"\nNumberF.abbreviate_number(1234567890)         # => \"1.2B\"\n```\n\nCombined with currency:\n\n```elixir\n\"$\" <> NumberF.abbreviate_number(1234567)     # => \"$1.2M\"\n```","ref":"currency-formatting.html#currency-abbreviations","title":"Currency Abbreviations - Currency Formatting","type":"extras"},{"doc":"The `NumberF.Currencies` module provides detailed information about different currencies:\n\n```elixir\n# Get information about a specific currency\ncurrency_info = NumberF.get_currency(\"EUR\")\n# => %{\n#   name: \"Euro\",\n#   symbol: \"€\",\n#   symbol_first: false,\n#   symbol_space: true,\n#   decimal_places: 2,\n#   thousands_separator: \".\",\n#   decimal_separator: \",\"\n# }\n\n# Format using specific currency rules\nNumberF.format_with_currency(1234.56, \"EUR\")  \n# => \"1.234,56 €\"\n```","ref":"currency-formatting.html#working-with-currency-information","title":"Working with Currency Information - Currency Formatting","type":"extras"},{"doc":"For currency conversion calculations:\n\n```elixir\n# Convert 100 USD to EUR with exchange rates\nNumberF.convert_currency(100, 1.0, 0.85)      # => 85.0  (USD to EUR)\n\n# Using with real-time exchange rates (pseudocode)\nusd_rate = get_exchange_rate(\"USD\")\neur_rate = get_exchange_rate(\"EUR\")\nNumberF.convert_currency(amount, usd_rate, eur_rate)\n```","ref":"currency-formatting.html#currency-conversion","title":"Currency Conversion - Currency Formatting","type":"extras"},{"doc":"For advanced internationalization, the `NumberF.I18n` module offers:\n\n```elixir\n# Get formatting rules for a specific locale\nlocale_settings = NumberF.I18n.get_locale_settings(\"fr-FR\")\n# => %{\n#   thousands_separator: \" \",\n#   decimal_separator: \",\",\n#   currency_symbol: \"€\",\n#   currency_symbol_first: false\n# }\n\n# Parse a localized number string back to a numeric value\nNumberF.I18n.parse_number(\"1 234,56\", \"fr-FR\")  # => 1234.56\n```","ref":"currency-formatting.html#internationalization-features","title":"Internationalization Features - Currency Formatting","type":"extras"},{"doc":"","ref":"currency-formatting.html#practical-examples","title":"Practical Examples - Currency Formatting","type":"extras"},{"doc":"```elixir\ndef display_price(price, user_locale \\\\ \"en-US\") do\n  NumberF.format_currency(price, user_locale)\nend\n\ndisplay_price(29.99)  # => \"$29.99\" for US users\ndisplay_price(29.99, \"fr-FR\")  # => \"29,99 €\" for French users\n```","ref":"currency-formatting.html#e-commerce-price-display","title":"E-commerce Price Display - Currency Formatting","type":"extras"},{"doc":"```elixir\ndef generate_financial_summary(revenue, expenses, profit, locale \\\\ \"en-US\") do\n  \"\"\"\n  Financial Summary\n  ================\n  Revenue: #{NumberF.format_currency(revenue, locale)}\n  Expenses: #{NumberF.format_currency(expenses, locale)}\n  Profit: #{NumberF.format_currency(profit, locale)}\n  Profit Margin: #{NumberF.percentage(profit, revenue)}%\n  \"\"\"\nend\n```","ref":"currency-formatting.html#financial-report-generation","title":"Financial Report Generation - Currency Formatting","type":"extras"},{"doc":"```elixir\ndef format_invoice_item(amount, original_currency, display_currency, exchange_rates) do\n  # Get rates for the currencies\n  original_rate = Map.get(exchange_rates, original_currency)\n  display_rate = Map.get(exchange_rates, display_currency)\n  \n  # Convert the amount\n  converted_amount = NumberF.convert_currency(amount, original_rate, display_rate)\n  \n  # Format both for display\n  original_formatted = NumberF.format_with_currency(amount, original_currency)\n  display_formatted = NumberF.format_with_currency(converted_amount, display_currency)\n  \n  \"#{original_formatted} (#{display_formatted})\"\nend\n```","ref":"currency-formatting.html#multi-currency-invoice","title":"Multi-currency Invoice - Currency Formatting","type":"extras"},{"doc":"1. **Use locale-aware formatting** for user-facing displays to respect cultural conventions\n2. **Store raw numbers** in your database, not formatted strings\n3. **Format at display time** based on user preferences or locale\n4. **Use appropriate precision** - most currencies use 2 decimal places, but some like JPY use 0\n5. **Handle nil values** - NumberF.currency returns nil for nil input, which is useful for optional values\n\nCurrency formatting is an essential part of any financial application. With NumberF, you have all the tools you need to handle currency values correctly and consistently across your application.","ref":"currency-formatting.html#best-practices","title":"Best Practices - Currency Formatting","type":"extras"},{"doc":"# Financial Calculations with NumberF\n\nThis guide explains how to use NumberF for financial calculations in your Elixir applications. From basic interest calculations to complex loan amortization, NumberF provides the tools you need for finance-related software.","ref":"financial-calculations.html","title":"Financial Calculations","type":"extras"},{"doc":"","ref":"financial-calculations.html#basic-interest-calculations","title":"Basic Interest Calculations - Financial Calculations","type":"extras"},{"doc":"Simple interest is calculated on the principal amount only:\n\n```elixir\n# Calculate simple interest (principal, rate, time in years)\nNumberF.simple_interest(1000, 0.05, 2)  # => 100.0\n# $1000 at 5% for 2 years = $100 interest\n\n# For larger amounts\nNumberF.simple_interest(50000, 0.03, 5)  # => 7500.0\n# $50,000 at 3% for 5 years = $7,500 interest\n```","ref":"financial-calculations.html#simple-interest","title":"Simple Interest - Financial Calculations","type":"extras"},{"doc":"Compound interest is calculated on both the principal and the accumulated interest:\n\n```elixir\n# Annual compounding (default)\nNumberF.compound_interest(1000, 0.05, 2)  # => 102.5\n# $1000 at 5% for 2 years with annual compounding = $102.50 interest\n\n# Monthly compounding (frequency = 12)\nNumberF.compound_interest(1000, 0.05, 2, 12)  # => 104.94\n# $1000 at 5% for 2 years with monthly compounding = $104.94 interest\n\n# Quarterly compounding (frequency = 4)\nNumberF.compound_interest(10000, 0.04, 10, 4)  # => 4889.32\n# $10,000 at 4% for 10 years with quarterly compounding = $4,889.32 interest\n```","ref":"financial-calculations.html#compound-interest","title":"Compound Interest - Financial Calculations","type":"extras"},{"doc":"","ref":"financial-calculations.html#loan-calculations","title":"Loan Calculations - Financial Calculations","type":"extras"},{"doc":"Calculate the Equated Monthly Installment for a loan:\n\n```elixir\n# Calculate EMI (principal, annual rate, term in months)\nNumberF.calculate_emi(100000, 0.10, 12)  # => 8791.59\n# $100,000 loan at 10% annual interest for 12 months = $8,791.59 monthly payment\n\n# Home loan example\nNumberF.calculate_emi(250000, 0.045, 360)  # => 1266.71\n# $250,000 mortgage at 4.5% for 30 years (360 months) = $1,266.71 monthly payment\n```","ref":"financial-calculations.html#monthly-installment-emi","title":"Monthly Installment (EMI) - Financial Calculations","type":"extras"},{"doc":"","ref":"financial-calculations.html#tax-calculations","title":"Tax Calculations - Financial Calculations","type":"extras"},{"doc":"```elixir\n# Calculate VAT (amount, rate)\nNumberF.calculate_vat(100, 0.2)  \n# => %{net: 100.0, vat: 20.0, gross: 120.0}\n\n# Calculate VAT from inclusive amount\nNumberF.calculate_vat(120, 0.2, true)  \n# => %{net: 100.0, vat: 20.0, gross: 120.0}\n```","ref":"financial-calculations.html#value-added-tax-vat","title":"Value Added Tax (VAT) - Financial Calculations","type":"extras"},{"doc":"```elixir\n# Calculate sales tax (amount, rate)\nNumberF.calculate_sales_tax(100, 0.06)  \n# => %{subtotal: 100.0, tax: 6.0, total: 106.0}\n\n# With custom rounding\nNumberF.calculate_sales_tax(100, 0.0625, round_to: 0.05)  \n# => %{subtotal: 100.0, tax: 6.25, total: 106.25}\n```","ref":"financial-calculations.html#sales-tax","title":"Sales Tax - Financial Calculations","type":"extras"},{"doc":"```elixir\n# UK tax brackets example\nbrackets = [{0, 0.0}, {12570, 0.2}, {50270, 0.4}, {150000, 0.45}]\n\n# Calculate income tax\nNumberF.Tax.calculate_income_tax(30000, brackets)  \n# => %{tax: 3486.0, effective_rate: 0.1162}\n# £30,000 salary results in £3,486 tax (11.62% effective rate)\n```","ref":"financial-calculations.html#income-tax","title":"Income Tax - Financial Calculations","type":"extras"},{"doc":"Convert amounts between currencies:\n\n```elixir\n# Basic conversion (amount, from_rate, to_rate)\nNumberF.convert_currency(100, 1, 0.85)  # => 85.0\n# $100 USD converted to EUR at 0.85 EUR/USD rate\n\n# Multi-currency calculation\namount_usd = 1000\nusd_to_eur_rate = 0.92\nusd_to_gbp_rate = 0.79\n\namount_eur = NumberF.convert_currency(amount_usd, 1, usd_to_eur_rate)  # => 920.0\namount_gbp = NumberF.convert_currency(amount_usd, 1, usd_to_gbp_rate)  # => 790.0\n```","ref":"financial-calculations.html#currency-conversion","title":"Currency Conversion - Financial Calculations","type":"extras"},{"doc":"Combining various functions for investment analysis:\n\n```elixir\n# Investment growth projection\ninitial_investment = 10000\nannual_rate = 0.07\nyears = 30\ncompounding_frequency = 12\n\nfinal_value = initial_investment + NumberF.compound_interest(\n  initial_investment, \n  annual_rate, \n  years, \n  compounding_frequency\n)\n\nformatted_result = NumberF.currency(final_value, \"$\")\n# => \"$ 76,122.51\" after 30 years\n\n# Calculate effective annual rate with monthly compounding\neffective_rate = (1 + annual_rate/12) ** 12 - 1\nannual_percentage = NumberF.percentage(effective_rate, 1, 2)\n# => 7.23%\n```","ref":"financial-calculations.html#investment-analysis","title":"Investment Analysis - Financial Calculations","type":"extras"},{"doc":"Example of creating a loan amortization schedule using NumberF:\n\n```elixir\ndefmodule LoanCalculator do\n  def generate_amortization_schedule(principal, annual_rate, term_months) do\n    # Calculate monthly payment\n    monthly_payment = NumberF.calculate_emi(principal, annual_rate, term_months)\n    \n    # Generate schedule\n    monthly_rate = annual_rate / 12\n    \n    Enum.reduce(1..term_months, {principal, []}, fn month, {remaining_principal, acc} ->\n      # Calculate interest for this period\n      interest_payment = remaining_principal * monthly_rate\n      \n      # Calculate principal for this period\n      principal_payment = monthly_payment - interest_payment\n      \n      # Calculate new remaining principal\n      new_remaining = remaining_principal - principal_payment\n      \n      # Create payment record\n      payment = %{\n        month: month,\n        payment: NumberF.round_with_precision(monthly_payment, 2),\n        principal: NumberF.round_with_precision(principal_payment, 2),\n        interest: NumberF.round_with_precision(interest_payment, 2),\n        remaining: max(0, NumberF.round_with_precision(new_remaining, 2))\n      }\n      \n      # Add to accumulator and continue\n      {new_remaining, [payment | acc]}\n    end)\n    |> elem(1)\n    |> Enum.reverse()\n  end\n  \n  def print_amortization_schedule(schedule) do\n    IO.puts \"Month | Payment | Principal | Interest | Remaining\"\n    IO.puts \"------|---------|-----------|----------|----------\"\n    \n    Enum.each(schedule, fn %{month: month, payment: payment, principal: principal,\n                             interest: interest, remaining: remaining} ->\n      IO.puts \"#{String.pad_leading(\"#{month}\", 5)} | #{NumberF.currency(payment, \"$\", 2)} | \" <>\n              \"#{NumberF.currency(principal, \"$\", 2)} | \" <>\n              \"#{NumberF.currency(interest, \"$\", 2)} | \" <>\n              \"#{NumberF.currency(remaining, \"$\", 2)}\"\n    end)\n  end\nend\n\n# Example usage:\nschedule = LoanCalculator.generate_amortization_schedule(10000, 0.06, 12)\nLoanCalculator.print_amortization_schedule(schedule)\n```","ref":"financial-calculations.html#loan-amortization-table","title":"Loan Amortization Table - Financial Calculations","type":"extras"},{"doc":"Example of real estate investment analysis:\n\n```elixir\ndefmodule RealEstateAnalysis do\n  def calculate_roi(purchase_price, closing_costs, repair_costs, annual_rental_income, \n                    annual_expenses, years_held, estimated_sale_price) do\n    # Total investment\n    total_investment = purchase_price + closing_costs + repair_costs\n    \n    # Annual cash flow\n    annual_cash_flow = annual_rental_income - annual_expenses\n    \n    # Total cash flow over holding period\n    total_cash_flow = annual_cash_flow * years_held\n    \n    # Profit from sale (simplified, not accounting for taxes)\n    sale_profit = estimated_sale_price - purchase_price\n    \n    # Total profit\n    total_profit = total_cash_flow + sale_profit\n    \n    # Calculate ROI\n    roi = NumberF.percentage(total_profit, total_investment, 2)\n    \n    # Calculate annual ROI\n    annual_roi = NumberF.percentage(total_profit / years_held, total_investment, 2)\n    \n    # Return analysis\n    %{\n      total_investment: NumberF.currency(total_investment, \"$\"),\n      total_cash_flow: NumberF.currency(total_cash_flow, \"$\"),\n      sale_profit: NumberF.currency(sale_profit, \"$\"),\n      total_profit: NumberF.currency(total_profit, \"$\"),\n      roi: \"#{roi}%\",\n      annual_roi: \"#{annual_roi}%\"\n    }\n  end\nend\n\n# Example usage:\nanalysis = RealEstateAnalysis.calculate_roi(\n  200000,    # Purchase price\n  5000,      # Closing costs\n  15000,     # Repair costs\n  24000,     # Annual rental income\n  10000,     # Annual expenses\n  5,         # Years held\n  250000     # Estimated sale price\n)\n\n# Result would show total ROI and annualized ROI for the investment\n```","ref":"financial-calculations.html#real-estate-financial-analysis","title":"Real Estate Financial Analysis - Financial Calculations","type":"extras"},{"doc":"1. **Use appropriate precision** - Financial calculations often require specific rounding rules\n2. **Be careful with floating point** - Use `NumberF.round_with_precision/2` to handle precision issues\n3. **Document your assumptions** - Financial formulas often make assumptions about compounding periods, etc.\n4. **Validate input data** - Financial calculations are sensitive to incorrect inputs\n5. **Use explicit parameter names** - Makes your code more readable and less error-prone\n\nNumberF provides a solid foundation for financial calculations in Elixir applications, from simple interest to complex investment analysis. By combining these tools with Elixir's excellent pattern matching and functional programming features, you can build robust financial software with clear, maintainable code.","ref":"financial-calculations.html#best-practices-for-financial-calculations","title":"Best Practices for Financial Calculations - Financial Calculations","type":"extras"},{"doc":"# Internationalization with NumberF\n\nThis guide covers the internationalization (i18n) features of NumberF, which allow you to format numbers according to the conventions of different locales and languages.","ref":"internationalization.html","title":"Internationalization","type":"extras"},{"doc":"Different regions format numbers differently, especially regarding:\n- Thousands separator (comma, period, space)\n- Decimal separator (comma, period)\n- Currency symbol placement (before/after the number)\n- Currency symbol spacing\n\nThe `NumberF.I18n` module handles these differences automatically:\n\n```elixir\n# Format a number according to locale conventions\nNumberF.format_number(1234567.89, \"en-US\")      # => \"1,234,567.89\"\nNumberF.format_number(1234567.89, \"fr-FR\")      # => \"1 234 567,89\"\nNumberF.format_number(1234567.89, \"de-DE\")      # => \"1.234.567,89\"\nNumberF.format_number(1234567.89, \"sv-SE\")      # => \"1 234 567,89\"\n```","ref":"internationalization.html#number-formatting-for-different-locales","title":"Number Formatting for Different Locales - Internationalization","type":"extras"},{"doc":"Currency formatting is even more varied across locales:\n\n```elixir\n# US Dollar format (symbol first, no space)\nNumberF.format_currency(1234.56, \"en-US\")       # => \"$1,234.56\"\n\n# Euro format in French locale (symbol after, with space)\nNumberF.format_currency(1234.56, \"fr-FR\")       # => \"1 234,56 €\"\n\n# Euro format in German locale\nNumberF.format_currency(1234.56, \"de-DE\")       # => \"1.234,56 €\"\n\n# British Pound format\nNumberF.format_currency(1234.56, \"en-GB\")       # => \"£1,234.56\"\n\n# Japanese Yen format (no decimal places)\nNumberF.format_currency(1234.56, \"ja-JP\")       # => \"¥1,235\"\n\n# Indian Rupee format (with special thousands grouping)\nNumberF.format_currency(1234567.89, \"hi-IN\")    # => \"₹12,34,567.89\"\n```","ref":"internationalization.html#currency-formatting-for-different-locales","title":"Currency Formatting for Different Locales - Internationalization","type":"extras"},{"doc":"You can also format a number with a specific currency, regardless of the locale:\n\n```elixir\n# Format with US locale but use Euro currency\nNumberF.format_currency(1234.56, \"en-US\", currency_code: \"EUR\")  \n# => \"€1,234.56\"\n\n# Format with German locale but use US Dollar\nNumberF.format_currency(1234.56, \"de-DE\", currency_code: \"USD\")  \n# => \"1.234,56 $\"\n```","ref":"internationalization.html#formatting-with-specific-currency","title":"Formatting with Specific Currency - Internationalization","type":"extras"},{"doc":"NumberF can spell out numbers in different languages:\n\n```elixir\n# English\nNumberF.spell_number(42, \"en\")                  # => \"Forty-two\"\n\n# French\nNumberF.spell_number(42, \"fr\")                  # => \"Quarante-deux\"\n\n# Spanish\nNumberF.spell_number(42, \"es\")                  # => \"Cuarenta y dos\"\n\n# German\nNumberF.spell_number(42, \"de\")                  # => \"Zweiundvierzig\"\n```\n\nYou can also include currency names:\n\n```elixir\n# English with currency\nNumberF.spell_number(42.75, \"en\", currency: true, currency_code: \"USD\")  \n# => \"Forty-two dollars and seventy-five cents\"\n\n# French with currency\nNumberF.spell_number(42.75, \"fr\", currency: true, currency_code: \"EUR\")  \n# => \"Quarante-deux euros et soixante-quinze centimes\"\n```","ref":"internationalization.html#spelling-numbers-in-different-languages","title":"Spelling Numbers in Different Languages - Internationalization","type":"extras"},{"doc":"You can parse number strings formatted according to different locale conventions:\n\n```elixir\n# Parse US-formatted number\nNumberF.I18n.parse_number(\"1,234.56\", \"en-US\")    # => 1234.56\n\n# Parse French-formatted number\nNumberF.I18n.parse_number(\"1 234,56\", \"fr-FR\")    # => 1234.56\n\n# Parse German-formatted number\nNumberF.I18n.parse_number(\"1.234,56\", \"de-DE\")    # => 1234.56\n```","ref":"internationalization.html#parsing-localized-number-strings","title":"Parsing Localized Number Strings - Internationalization","type":"extras"},{"doc":"If you need to access the formatting rules for a specific locale:\n\n```elixir\n# Get locale settings\nNumberF.I18n.get_locale_settings(\"fr-FR\")\n# => %{\n#   thousands_separator: \" \",\n#   decimal_separator: \",\",\n#   currency_symbol: \"€\",\n#   currency_symbol_first: false\n# }\n\n# Get currency names for a specific currency and language\nNumberF.I18n.get_currency_names(\"USD\", \"en\")\n# => %{main: \"dollars\", sub: \"cents\"}\n```","ref":"internationalization.html#getting-locale-information","title":"Getting Locale Information - Internationalization","type":"extras"},{"doc":"NumberF supports a wide range of locales, including:\n\n**European:**\n- English (UK): \"en-GB\"\n- English (US): \"en-US\"\n- French: \"fr-FR\"\n- German: \"de-DE\"\n- Spanish: \"es-ES\"\n- Italian: \"it-IT\"\n- Dutch: \"nl-NL\"\n- Swedish: \"sv-SE\"\n- Portuguese (Portugal): \"pt-PT\"\n- Portuguese (Brazil): \"pt-BR\"\n- Polish: \"pl-PL\"\n- Russian: \"ru-RU\"\n\n**Asian:**\n- Japanese: \"ja-JP\"\n- Chinese (Simplified): \"zh-CN\"\n- Chinese (Traditional): \"zh-TW\"\n- Korean: \"ko-KR\"\n- Thai: \"th-TH\"\n- Vietnamese: \"vi-VN\"\n- Hindi: \"hi-IN\"\n\n**Middle Eastern:**\n- Arabic (Saudi Arabia): \"ar-SA\"\n- Turkish: \"tr-TR\"\n\n**African:**\n- Zambian: \"en-ZM\"\n- South African: \"en-ZA\"","ref":"internationalization.html#supported-locales","title":"Supported Locales - Internationalization","type":"extras"},{"doc":"","ref":"internationalization.html#practical-examples","title":"Practical Examples - Internationalization","type":"extras"},{"doc":"```elixir\ndefmodule Store.ProductView do\n  # Display product price based on user's locale\n  def display_price(price, user_locale \\\\ \"en-US\") do\n    NumberF.format_currency(price, user_locale)\n  end\n  \n  # Format product specs with appropriate number formats\n  def format_specs(weight_kg, dimensions_cm, user_locale) do\n    formatted_weight = NumberF.format_number(weight_kg, user_locale)\n    [width, height, depth] = dimensions_cm\n    \n    formatted_dimensions = \n      dimensions_cm\n      |> Enum.map(fn dim -> NumberF.format_number(dim, user_locale) end)\n      |> Enum.join(\" × \")\n      \n    %{\n      weight: \"#{formatted_weight} kg\",\n      dimensions: \"#{formatted_dimensions} cm\"\n    }\n  end\nend\n```","ref":"internationalization.html#multilingual-e-commerce-application","title":"Multilingual E-commerce Application - Internationalization","type":"extras"},{"doc":"```elixir\ndefmodule Billing.InvoiceGenerator do\n  def generate_invoice(items, subtotal, tax_rate, customer_locale) do\n    # Calculate values\n    tax_amount = subtotal * tax_rate\n    total = subtotal + tax_amount\n    \n    # Format all monetary values according to customer's locale\n    formatted_items = Enum.map(items, fn {desc, price} ->\n      {desc, NumberF.format_currency(price, customer_locale)}\n    end)\n    \n    formatted_subtotal = NumberF.format_currency(subtotal, customer_locale)\n    formatted_tax = NumberF.format_currency(tax_amount, customer_locale)\n    formatted_total = NumberF.format_currency(total, customer_locale)\n    tax_percentage = NumberF.percentage(tax_rate, 1, 1)\n    \n    # Generate invoice with proper formatting\n    %{\n      items: formatted_items,\n      subtotal: formatted_subtotal,\n      tax_rate: \"#{tax_percentage}%\",\n      tax_amount: formatted_tax,\n      total: formatted_total,\n      total_in_words: NumberF.spell_number(\n        total, \n        get_language_from_locale(customer_locale),\n        currency: true, \n        currency_code: get_currency_from_locale(customer_locale)\n      )\n    }\n  end\n  \n  # Helper to extract language code from locale\n  defp get_language_from_locale(locale) do\n    [language, _] = String.split(locale, \"-\")\n    language\n  end\n  \n  # Helper to get default currency for locale\n  defp get_currency_from_locale(\"en-US\"), do: \"USD\"\n  defp get_currency_from_locale(\"en-GB\"), do: \"GBP\"\n  defp get_currency_from_locale(\"fr-FR\"), do: \"EUR\"\n  defp get_currency_from_locale(\"de-DE\"), do: \"EUR\"\n  defp get_currency_from_locale(\"ja-JP\"), do: \"JPY\"\n  defp get_currency_from_locale(\"en-ZM\"), do: \"ZMW\"\n  defp get_currency_from_locale(_), do: \"USD\"  # Default\nend\n```","ref":"internationalization.html#international-invoice-generation","title":"International Invoice Generation - Internationalization","type":"extras"},{"doc":"```elixir\ndefmodule Finance.Report do\n  def generate_multi_currency_report(amounts, base_currency, target_currencies, exchange_rates) do\n    # Get base rate\n    base_rate = Map.get(exchange_rates, base_currency)\n    \n    # For each target currency, convert and format\n    currency_rows = Enum.map(target_currencies, fn currency ->\n      rate = Map.get(exchange_rates, currency)\n      converted = NumberF.convert_currency(amounts.revenue, base_rate, rate)\n      \n      %{\n        currency: currency,\n        amount: NumberF.format_currency(converted, \"en-US\", currency_code: currency),\n        exchange_rate: \"#{base_currency}/#{currency}: #{rate/base_rate}\"\n      }\n    end)\n    \n    # Base currency amount\n    base = %{\n      currency: base_currency,\n      amount: NumberF.format_currency(amounts.revenue, \"en-US\", currency_code: base_currency),\n      exchange_rate: \"1.0\"\n    }\n    \n    [base | currency_rows]\n  end\nend\n```","ref":"internationalization.html#financial-report-with-multiple-currencies","title":"Financial Report with Multiple Currencies - Internationalization","type":"extras"},{"doc":"1. **Default to user's locale** when possible\n2. **Store raw numbers** in your database, not formatted strings\n3. **Format at display time** based on user preferences\n4. **Test with multiple locales** to ensure proper formatting\n5. **Consider right-to-left languages** when designing UI layout\n6. **Allow users to override** locale-based defaults when needed\n\nWith NumberF's internationalization features, your Elixir applications can provide a consistent, culturally appropriate experience for users around the world.","ref":"internationalization.html#best-practices-for-internationalization","title":"Best Practices for Internationalization - Internationalization","type":"extras"},{"doc":"# Changelog\n\nAll notable changes to the NumberF library will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.2.0] - 2025-05-17","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"- **Internationalization Module** (`NumberF.I18n`)\n  - Added locale-specific number formatting for 25+ locales\n  - Added multi-language number spelling (English, French, Spanish, German)\n  - Added currency-specific formatting rules\n\n- **Metrics Module** (`NumberF.Metrics`)\n  - Added conversion between metric and imperial units\n  - Added temperature conversion (Celsius/Fahrenheit)\n  - Added customizable unit conversion framework\n\n- **Tax Module** (`NumberF.Tax`)\n  - Added VAT calculation with inclusive/exclusive options\n  - Added sales tax calculation with configurable rounding\n  - Added income tax calculation with progressive brackets\n  - Added capital gains tax calculation\n  - Added withholding tax calculation\n  - Added corporate tax calculation\n  - Added payroll tax calculation\n\n- **Precision Module** (`NumberF.Precision`)\n  - Added bankers rounding (round to even)\n  - Added custom rounding for different thresholds\n  - Added approximate equality testing for floating point\n  - Added sanitization for special values (NaN, Infinity)\n\n- **Currencies Module** (`NumberF.Currencies`)\n  - Added comprehensive currency information database\n  - Added currency-specific formatting rules\n  - Added multi-currency conversion framework\n\n- **Registry Module** (`NumberF.Registry`)\n  - Added module and function discovery utilities\n  - Added documentation generator","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- **Core Module** (`NumberF`)\n  - Enhanced organization for better discoverability\n  - Added direct access to functionality from submodules\n  - Improved documentation with detailed examples\n  - Fixed naming conflicts with Kernel functions\n\n- **Documentation**\n  - Added comprehensive examples\n  - Categorized functions for easier navigation\n  - Added cross-references between related functions\n  - More detailed parameter descriptions","ref":"changelog.html#improved","title":"Improved - Changelog","type":"extras"},{"doc":"- Resolved precision issues in floating-point calculations\n- Fixed currency symbol placement for different locales\n- Addressed multiple default parameter declaration issues\n\n## [0.1.4] - 2025-01-20","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Initial release with basic functionality\n- Currency formatting\n- Number to words conversion\n- Financial calculations\n- Statistical functions\n- Memory size formatting\n- Random string generation\n- Basic type conversion utilities","ref":"changelog.html#added-1","title":"Added - Changelog","type":"extras"},{"doc":"# Contributing to NumberF\n\nThank you for considering contributing to NumberF! This document provides guidelines and instructions for contributing to make the process smooth for everyone.","ref":"contributing.html","title":"Contributing","type":"extras"},{"doc":"By participating in this project, you agree to maintain a welcoming, inclusive, and harassment-free environment. Please be respectful toward others.","ref":"contributing.html#code-of-conduct","title":"Code of Conduct - Contributing","type":"extras"},{"doc":"","ref":"contributing.html#how-can-i-contribute","title":"How Can I Contribute? - Contributing","type":"extras"},{"doc":"If you encounter a bug, please create an issue with the following information:\n- Clear title that summarizes the issue\n- Steps to reproduce the behavior\n- Expected behavior\n- Actual behavior\n- Elixir and NumberF versions\n- Any additional context that might be helpful","ref":"contributing.html#reporting-bugs","title":"Reporting Bugs - Contributing","type":"extras"},{"doc":"We welcome feature suggestions! When suggesting enhancements:\n- Use a clear title for the issue\n- Provide a detailed description of the suggested enhancement\n- Explain why this enhancement would be useful\n- List example use cases if applicable","ref":"contributing.html#suggesting-enhancements","title":"Suggesting Enhancements - Contributing","type":"extras"},{"doc":"1. Fork the repository\n2. Create a new branch for your feature (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add some amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request\n\n#### Pull Request Guidelines\n\n- Update the README.md with details of changes if applicable\n- Update the CHANGELOG.md with details of changes\n- The PR should work with all supported Elixir versions\n- Ensure all tests pass\n- Add tests for new features to ensure code coverage\n- Follow the existing code style","ref":"contributing.html#pull-requests","title":"Pull Requests - Contributing","type":"extras"},{"doc":"1. Clone the repository\n   ```bash\n   git clone https://github.com/jamesnjovu/elixir_number_functions.git\n   cd number_f\n   ```\n\n2. Install dependencies\n   ```bash\n   mix deps.get\n   ```\n\n3. Run tests\n   ```bash\n   mix test\n   ```\n\n4. Run code formatting\n   ```bash\n   mix format\n   ```","ref":"contributing.html#development-setup","title":"Development Setup - Contributing","type":"extras"},{"doc":"","ref":"contributing.html#styleguides","title":"Styleguides - Contributing","type":"extras"},{"doc":"- Use the present tense (\"Add feature\" not \"Added feature\")\n- Use the imperative mood (\"Move cursor to...\" not \"Moves cursor to...\")\n- Limit the first line to 72 characters or less\n- Reference issues and pull requests after the first line","ref":"contributing.html#git-commit-messages","title":"Git Commit Messages - Contributing","type":"extras"},{"doc":"- Follow the [Elixir Style Guide](https://github.com/christopheradams/elixir_style_guide)\n- Run `mix format` before committing","ref":"contributing.html#elixir-styleguide","title":"Elixir Styleguide - Contributing","type":"extras"},{"doc":"- Use [ExDoc](https://hexdocs.pm/ex_doc/readme.html) syntax\n- Include examples in function documentation\n- Keep explanations clear and concise","ref":"contributing.html#documentation-styleguide","title":"Documentation Styleguide - Contributing","type":"extras"},{"doc":"When adding new modules or functions, please follow the existing structure:\n\n- Core functionality in the main `NumberF` module\n- Specialized functions in appropriate submodules\n- Add exports to the main module for commonly used functionality","ref":"contributing.html#module-structure","title":"Module Structure - Contributing","type":"extras"},{"doc":"When adding new features:\n\n1. Add appropriate test coverage\n2. Add thorough documentation with examples\n3. Update type specifications if applicable\n4. Consider internationalization implications\n5. Update the README.md if the feature is user-facing","ref":"contributing.html#adding-new-features","title":"Adding New Features - Contributing","type":"extras"},{"doc":"If you have any questions about contributing, please open an issue for discussion.\n\nThank you for helping improve NumberF!","ref":"contributing.html#questions","title":"Questions? - Contributing","type":"extras"}],"producer":{"name":"ex_doc","version":"0.38.1"},"proglang":"elixir"}